Class: Google::Apis::NetworkmanagementV1beta1::Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Source or destination of the Connectivity Test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Endpoint

Returns a new instance of Endpoint.



1063
1064
1065
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_versionGoogle::Apis::NetworkmanagementV1beta1::AppEngineVersionEndpoint

Wrapper for the App Engine service version attributes. Corresponds to the JSON property appEngineVersion



932
933
934
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 932

def app_engine_version
  @app_engine_version
end

#cloud_functionGoogle::Apis::NetworkmanagementV1beta1::CloudFunctionEndpoint

Wrapper for Cloud Function attributes. Corresponds to the JSON property cloudFunction



937
938
939
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 937

def cloud_function
  @cloud_function
end

#cloud_run_jobString

A Cloud Run job URI. Applicable only to source endpoint. The format is: projects/project/locations/location /jobs/job Corresponds to the JSON property cloudRunJob

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 945

def cloud_run_job
  @cloud_run_job
end

#cloud_run_revisionGoogle::Apis::NetworkmanagementV1beta1::CloudRunRevisionEndpoint

Wrapper for Cloud Run revision attributes. Corresponds to the JSON property cloudRunRevision



950
951
952
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 950

def cloud_run_revision
  @cloud_run_revision
end

#cloud_sql_instanceString

A Cloud SQL instance URI. Corresponds to the JSON property cloudSqlInstance

Returns:

  • (String)


955
956
957
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 955

def cloud_sql_instance
  @cloud_sql_instance
end

#datastream_private_connectionString

A Datastream Private Connection name format: projects/project/locations/location/privateConnections/privateConnection. Corresponds to the JSON property datastreamPrivateConnection

Returns:

  • (String)


962
963
964
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 962

def datastream_private_connection
  @datastream_private_connection
end

#dms_private_connectionString

A DMS Private Connection name format: projects/project/locations/location/privateConnections/privateConnection. Corresponds to the JSON property dmsPrivateConnection

Returns:

  • (String)


969
970
971
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 969

def dms_private_connection
  @dms_private_connection
end

#forwarding_ruleString

A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules are also used for protocol forwarding, Private Service Connect and other network services to provide forwarding information in the control plane. Applicable only to destination endpoint. Format: projects/project/global/forwardingRules/id or `projects/`project`/regions/`region`/forwardingRules/`id Corresponds to the JSON property forwardingRule

Returns:

  • (String)


979
980
981
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 979

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_targetString

Output only. Specifies the type of the target of the forwarding rule. Corresponds to the JSON property forwardingRuleTarget

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 984

def forwarding_rule_target
  @forwarding_rule_target
end

#fqdnString

DNS endpoint of Google Kubernetes Engine cluster control plane. Requires gke_master_cluster to be set, can't be used simultaneoulsly with ip_address or network. Applicable only to destination endpoint. Corresponds to the JSON property fqdn

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 992

def fqdn
  @fqdn
end

#gke_master_clusterString

A cluster URI for Google Kubernetes Engine cluster control plane. Corresponds to the JSON property gkeMasterCluster

Returns:

  • (String)


998
999
1000
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 998

def gke_master_cluster
  @gke_master_cluster
end

#gke_podString

A GKE Pod URI. Corresponds to the JSON property gkePod

Returns:

  • (String)


1003
1004
1005
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1003

def gke_pod
  @gke_pod
end

#instanceString

A Compute Engine instance URI. Corresponds to the JSON property instance

Returns:

  • (String)


1008
1009
1010
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1008

def instance
  @instance
end

#ip_addressString

The IP address of the endpoint, which can be an external or internal IP. Corresponds to the JSON property ipAddress

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1013

def ip_address
  @ip_address
end

#load_balancer_idString

Output only. ID of the load balancer the forwarding rule points to. Empty for forwarding rules not related to load balancers. Corresponds to the JSON property loadBalancerId

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1019

def load_balancer_id
  @load_balancer_id
end

#load_balancer_typeString

Output only. Type of the load balancer the forwarding rule points to. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1024

def load_balancer_type
  @load_balancer_type
end

#networkString

A VPC network URI. For source endpoints, used according to the network_type. For destination endpoints, used only when the source is an external IP address endpoint, and the destination is an internal IP address endpoint. Corresponds to the JSON property network

Returns:

  • (String)


1031
1032
1033
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1031

def network
  @network
end

#network_typeString

For source endpoints, type of the network where the endpoint is located. Not relevant for destination endpoints. Corresponds to the JSON property networkType

Returns:

  • (String)


1037
1038
1039
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1037

def network_type
  @network_type
end

#portFixnum

The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1043
1044
1045
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1043

def port
  @port
end

#project_idString

For source endpoints, endpoint project ID. Used according to the network_type . Not relevant for destination endpoints. Corresponds to the JSON property projectId

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1049

def project_id
  @project_id
end

#redis_clusterString

A Redis Cluster URI. Applicable only to destination endpoint. Corresponds to the JSON property redisCluster

Returns:

  • (String)


1055
1056
1057
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1055

def redis_cluster
  @redis_cluster
end

#redis_instanceString

A Redis Instance URI. Applicable only to destination endpoint. Corresponds to the JSON property redisInstance

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1061

def redis_instance
  @redis_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1068

def update!(**args)
  @app_engine_version = args[:app_engine_version] if args.key?(:app_engine_version)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run_job = args[:cloud_run_job] if args.key?(:cloud_run_job)
  @cloud_run_revision = args[:cloud_run_revision] if args.key?(:cloud_run_revision)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @datastream_private_connection = args[:datastream_private_connection] if args.key?(:datastream_private_connection)
  @dms_private_connection = args[:dms_private_connection] if args.key?(:dms_private_connection)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_target = args[:forwarding_rule_target] if args.key?(:forwarding_rule_target)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @gke_master_cluster = args[:gke_master_cluster] if args.key?(:gke_master_cluster)
  @gke_pod = args[:gke_pod] if args.key?(:gke_pod)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
  @network = args[:network] if args.key?(:network)
  @network_type = args[:network_type] if args.key?(:network_type)
  @port = args[:port] if args.key?(:port)
  @project_id = args[:project_id] if args.key?(:project_id)
  @redis_cluster = args[:redis_cluster] if args.key?(:redis_cluster)
  @redis_instance = args[:redis_instance] if args.key?(:redis_instance)
end