Class: Google::Apis::NetworkmanagementV1beta1::EndpointInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointInfo

Returns a new instance of EndpointInfo.



1142
1143
1144
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Corresponds to the JSON property destinationIp

Returns:

  • (String)


1103
1104
1105
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1103

def destination_ip
  @destination_ip
end

#destination_network_uriString

URI of the network where this packet is sent to. Format: projects/project_id /global/networks/network_id` Corresponds to the JSON propertydestinationNetworkUri`

Returns:

  • (String)


1109
1110
1111
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1109

def destination_network_uri
  @destination_network_uri
end

#destination_portFixnum

Destination port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


1114
1115
1116
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1114

def destination_port
  @destination_port
end

#protocolString

IP protocol in string format, for example: "TCP", "UDP", "ICMP". Corresponds to the JSON property protocol

Returns:

  • (String)


1119
1120
1121
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1119

def protocol
  @protocol
end

#source_agent_uriString

URI of the source telemetry agent this packet originates from. Corresponds to the JSON property sourceAgentUri

Returns:

  • (String)


1124
1125
1126
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1124

def source_agent_uri
  @source_agent_uri
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


1129
1130
1131
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1129

def source_ip
  @source_ip
end

#source_network_uriString

URI of the network where this packet originates from. Format: projects/ project_id/global/networks/network_id` Corresponds to the JSON propertysourceNetworkUri`

Returns:

  • (String)


1135
1136
1137
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1135

def source_network_uri
  @source_network_uri
end

#source_portFixnum

Source port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


1140
1141
1142
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1140

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1147

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri)
  @source_port = args[:source_port] if args.key?(:source_port)
end