Class: Google::Apis::NetworkmanagementV1beta1::HybridSubnetInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::HybridSubnetInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a hybrid subnet.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a hybrid subnet.
-
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
-
#uri ⇒ String
URI of a hybrid subnet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HybridSubnetInfo
constructor
A new instance of HybridSubnetInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HybridSubnetInfo
Returns a new instance of HybridSubnetInfo.
1556 1557 1558 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1556 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a hybrid subnet.
Corresponds to the JSON property displayName
1544 1545 1546 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1544 def display_name @display_name end |
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
Corresponds to the JSON property region
1549 1550 1551 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1549 def region @region end |
#uri ⇒ String
URI of a hybrid subnet.
Corresponds to the JSON property uri
1554 1555 1556 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1554 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1561 1562 1563 1564 1565 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1561 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |