Class: Google::Apis::NetworkmanagementV1beta1::ListVpcFlowLogsConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::ListVpcFlowLogsConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
Response for the ListVpcFlowLogsConfigs method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-). -
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1beta1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
constructor
A new instance of ListVpcFlowLogsConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
Returns a new instance of ListVpcFlowLogsConfigsResponse.
1886 1887 1888 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
Corresponds to the JSON property nextPageToken
1874 1875 1876 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1874 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
1879 1880 1881 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1879 def unreachable @unreachable end |
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1beta1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Corresponds to the JSON property vpcFlowLogsConfigs
1884 1885 1886 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1884 def vpc_flow_logs_configs @vpc_flow_logs_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1891 1892 1893 1894 1895 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1891 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @vpc_flow_logs_configs = args[:vpc_flow_logs_configs] if args.key?(:vpc_flow_logs_configs) end |