Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a specific load balancer backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerBackend

Returns a new instance of LoadBalancerBackend.



1967
1968
1969
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine instance or network endpoint. Corresponds to the JSON property displayName

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1945

def display_name
  @display_name
end

#health_check_allowing_firewall_rulesArray<String>

A list of firewall rule URIs allowing probes from health check IP ranges. Corresponds to the JSON property healthCheckAllowingFirewallRules

Returns:

  • (Array<String>)


1950
1951
1952
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1950

def health_check_allowing_firewall_rules
  @health_check_allowing_firewall_rules
end

#health_check_blocking_firewall_rulesArray<String>

A list of firewall rule URIs blocking probes from health check IP ranges. Corresponds to the JSON property healthCheckBlockingFirewallRules

Returns:

  • (Array<String>)


1955
1956
1957
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1955

def health_check_blocking_firewall_rules
  @health_check_blocking_firewall_rules
end

#health_check_firewall_stateString

State of the health check firewall configuration. Corresponds to the JSON property healthCheckFirewallState

Returns:

  • (String)


1960
1961
1962
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1960

def health_check_firewall_state
  @health_check_firewall_state
end

#uriString

URI of a Compute Engine instance or network endpoint. Corresponds to the JSON property uri

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1965

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1972
1973
1974
1975
1976
1977
1978
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1972

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @health_check_allowing_firewall_rules = args[:health_check_allowing_firewall_rules] if args.key?(:health_check_allowing_firewall_rules)
  @health_check_blocking_firewall_rules = args[:health_check_blocking_firewall_rules] if args.key?(:health_check_blocking_firewall_rules)
  @health_check_firewall_state = args[:health_check_firewall_state] if args.key?(:health_check_firewall_state)
  @uri = args[:uri] if args.key?(:uri)
end