Class: Google::Apis::NetworkmanagementV1beta1::NetworkInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::NetworkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine network.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine network.
-
#matched_ip_range ⇒ String
The IP range of the subnet matching the source IP address of the test.
-
#matched_subnet_uri ⇒ String
URI of the subnet matching the source IP address of the test in format " projects/
project/regions/region/subnetworks/subnetwork" Corresponds to the JSON propertymatchedSubnetUri. -
#region ⇒ String
The region of the subnet matching the source IP address of the test.
-
#uri ⇒ String
URI of a Compute Engine network in format "projects/
project/global/networks/network" Corresponds to the JSON propertyuri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInfo
constructor
A new instance of NetworkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInfo
Returns a new instance of NetworkInfo.
2364 2365 2366 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine network.
Corresponds to the JSON property displayName
2340 2341 2342 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2340 def display_name @display_name end |
#matched_ip_range ⇒ String
The IP range of the subnet matching the source IP address of the test.
Corresponds to the JSON property matchedIpRange
2345 2346 2347 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2345 def matched_ip_range @matched_ip_range end |
#matched_subnet_uri ⇒ String
URI of the subnet matching the source IP address of the test in format "
projects/project/regions/region/subnetworks/subnetwork"
Corresponds to the JSON property matchedSubnetUri
2351 2352 2353 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2351 def matched_subnet_uri @matched_subnet_uri end |
#region ⇒ String
The region of the subnet matching the source IP address of the test.
Corresponds to the JSON property region
2356 2357 2358 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2356 def region @region end |
#uri ⇒ String
URI of a Compute Engine network in format "projects/project/global/networks/
network"
Corresponds to the JSON property uri
2362 2363 2364 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2362 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2369 2370 2371 2372 2373 2374 2375 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2369 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range) @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |