Class: Google::Apis::NetworkmanagementV1beta1::NgfwPacketInspectionInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::NgfwPacketInspectionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a layer 7 packet inspection by the firewall.
Instance Attribute Summary collapse
-
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet inspection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NgfwPacketInspectionInfo
constructor
A new instance of NgfwPacketInspectionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NgfwPacketInspectionInfo
Returns a new instance of NgfwPacketInspectionInfo.
2266 2267 2268 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet
inspection.
Corresponds to the JSON property securityProfileGroupUri
2264 2265 2266 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2264 def security_profile_group_uri @security_profile_group_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2271 2272 2273 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2271 def update!(**args) @security_profile_group_uri = args[:security_profile_group_uri] if args.key?(:security_profile_group_uri) end |