Class: Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Cloud Redis Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedisInstanceInfo

Returns a new instance of RedisInstanceInfo.



2967
2968
2969
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Cloud Redis Instance. Corresponds to the JSON property displayName

Returns:

  • (String)


2938
2939
2940
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2938

def display_name
  @display_name
end

#network_uriString

URI of a Cloud Redis Instance network in format "projects/project/global/ networks/network". Corresponds to the JSON property networkUri

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2944

def network_uri
  @network_uri
end

#primary_endpoint_ipString

Primary endpoint IP address of a Cloud Redis Instance. Corresponds to the JSON property primaryEndpointIp

Returns:

  • (String)


2949
2950
2951
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2949

def primary_endpoint_ip
  @primary_endpoint_ip
end

#read_endpoint_ipString

Read endpoint IP address of a Cloud Redis Instance (if applicable). Corresponds to the JSON property readEndpointIp

Returns:

  • (String)


2954
2955
2956
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2954

def read_endpoint_ip
  @read_endpoint_ip
end

#regionString

Region in which the Cloud Redis Instance is defined. Corresponds to the JSON property region

Returns:

  • (String)


2959
2960
2961
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2959

def region
  @region
end

#uriString

URI of a Cloud Redis Instance in format "projects/project/locations/ location/instances/instance" Corresponds to the JSON property uri

Returns:

  • (String)


2965
2966
2967
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2965

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2972

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip)
  @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end