Class: Google::Apis::NetworkmanagementV1beta1::SingleEdgeResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::SingleEdgeResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
Probing results for a single edge device.
Instance Attribute Summary collapse
-
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1beta1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations.
-
#destination_router ⇒ String
Router name in the format '
router.metroshard'. -
#probing_latency ⇒ Google::Apis::NetworkmanagementV1beta1::LatencyDistribution
Describes measured latency distribution.
-
#result ⇒ String
The overall result of active probing for this egress device.
-
#sent_probe_count ⇒ Fixnum
Number of probes sent.
-
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleEdgeResponse
constructor
A new instance of SingleEdgeResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleEdgeResponse
Returns a new instance of SingleEdgeResponse.
3321 3322 3323 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1beta1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/
docs/edge-locations.
Corresponds to the JSON property destinationEgressLocation
3293 3294 3295 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3293 def destination_egress_location @destination_egress_location end |
#destination_router ⇒ String
Router name in the format 'router.metroshard'. For example: pf01.aaa01,
pr02.aaa01.
Corresponds to the JSON property destinationRouter
3299 3300 3301 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3299 def destination_router @destination_router end |
#probing_latency ⇒ Google::Apis::NetworkmanagementV1beta1::LatencyDistribution
Describes measured latency distribution.
Corresponds to the JSON property probingLatency
3304 3305 3306 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3304 def probing_latency @probing_latency end |
#result ⇒ String
The overall result of active probing for this egress device.
Corresponds to the JSON property result
3309 3310 3311 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3309 def result @result end |
#sent_probe_count ⇒ Fixnum
Number of probes sent.
Corresponds to the JSON property sentProbeCount
3314 3315 3316 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3314 def sent_probe_count @sent_probe_count end |
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Corresponds to the JSON property successfulProbeCount
3319 3320 3321 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3319 def successful_probe_count @successful_probe_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3326 def update!(**args) @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location) @destination_router = args[:destination_router] if args.key?(:destination_router) @probing_latency = args[:probing_latency] if args.key?(:probing_latency) @result = args[:result] if args.key?(:result) @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count) @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count) end |