Class: Google::Apis::NetworkmanagementV1beta1::Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
Source or destination of the Connectivity Test.
Instance Attribute Summary collapse
-
#app_engine_version ⇒ Google::Apis::NetworkmanagementV1beta1::AppEngineVersionEndpoint
Wrapper for the App Engine service version attributes.
-
#cloud_function ⇒ Google::Apis::NetworkmanagementV1beta1::CloudFunctionEndpoint
Wrapper for Cloud Function attributes.
- #cloud_run_job ⇒ String
-
#cloud_run_revision ⇒ Google::Apis::NetworkmanagementV1beta1::CloudRunRevisionEndpoint
Wrapper for Cloud Run revision attributes.
-
#cloud_sql_instance ⇒ String
A Cloud SQL instance URI.
-
#datastream_private_connection ⇒ String
A Datastream Private Connection name format: projects/
project/locations/location/privateConnections/privateConnection. -
#dms_private_connection ⇒ String
A DMS Private Connection name format: projects/
project/locations/location/privateConnections/privateConnection. -
#forwarding_rule ⇒ String
A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer.
-
#forwarding_rule_target ⇒ String
Output only.
-
#fqdn ⇒ String
DNS endpoint of Google Kubernetes Engine cluster control plane.
-
#gke_master_cluster ⇒ String
A cluster URI for Google Kubernetes Engine cluster control plane.
-
#gke_pod ⇒ String
A GKE Pod URI.
-
#instance ⇒ String
A Compute Engine instance URI.
-
#ip_address ⇒ String
The IP address of the endpoint, which can be an external or internal IP.
-
#load_balancer_id ⇒ String
Output only.
-
#load_balancer_type ⇒ String
Output only.
-
#network ⇒ String
A VPC network URI.
-
#network_type ⇒ String
For source endpoints, type of the network where the endpoint is located.
-
#port ⇒ Fixnum
The IP protocol port of the endpoint.
-
#project_id ⇒ String
For source endpoints, endpoint project ID.
-
#redis_cluster ⇒ String
A Redis Cluster URI.
-
#redis_instance ⇒ String
A Redis Instance URI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Endpoint
constructor
A new instance of Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Endpoint
Returns a new instance of Endpoint.
1019 1020 1021 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_engine_version ⇒ Google::Apis::NetworkmanagementV1beta1::AppEngineVersionEndpoint
Wrapper for the App Engine service version attributes.
Corresponds to the JSON property appEngineVersion
888 889 890 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 888 def app_engine_version @app_engine_version end |
#cloud_function ⇒ Google::Apis::NetworkmanagementV1beta1::CloudFunctionEndpoint
Wrapper for Cloud Function attributes.
Corresponds to the JSON property cloudFunction
893 894 895 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 893 def cloud_function @cloud_function end |
#cloud_run_job ⇒ String
901 902 903 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 901 def cloud_run_job @cloud_run_job end |
#cloud_run_revision ⇒ Google::Apis::NetworkmanagementV1beta1::CloudRunRevisionEndpoint
Wrapper for Cloud Run revision attributes.
Corresponds to the JSON property cloudRunRevision
906 907 908 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 906 def cloud_run_revision @cloud_run_revision end |
#cloud_sql_instance ⇒ String
A Cloud SQL instance URI.
Corresponds to the JSON property cloudSqlInstance
911 912 913 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 911 def cloud_sql_instance @cloud_sql_instance end |
#datastream_private_connection ⇒ String
A Datastream Private Connection name format:
projects/project/locations/location/privateConnections/privateConnection.
Corresponds to the JSON property datastreamPrivateConnection
918 919 920 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 918 def datastream_private_connection @datastream_private_connection end |
#dms_private_connection ⇒ String
A DMS Private Connection name format:
projects/project/locations/location/privateConnections/privateConnection.
Corresponds to the JSON property dmsPrivateConnection
925 926 927 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 925 def dms_private_connection @dms_private_connection end |
#forwarding_rule ⇒ String
A forwarding rule and its corresponding IP address represent the frontend
configuration of a Google Cloud load balancer. Forwarding rules are also used
for protocol forwarding, Private Service Connect and other network services to
provide forwarding information in the control plane. Applicable only to
destination endpoint. Format: projects/project/global/forwardingRules/id
or `projects/`project`/regions/`region`/forwardingRules/`id
Corresponds to the JSON property forwardingRule
935 936 937 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 935 def forwarding_rule @forwarding_rule end |
#forwarding_rule_target ⇒ String
Output only. Specifies the type of the target of the forwarding rule.
Corresponds to the JSON property forwardingRuleTarget
940 941 942 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 940 def forwarding_rule_target @forwarding_rule_target end |
#fqdn ⇒ String
DNS endpoint of Google Kubernetes Engine cluster control plane. Requires
gke_master_cluster to be set, can't be used simultaneoulsly with ip_address or
network. Applicable only to destination endpoint.
Corresponds to the JSON property fqdn
948 949 950 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 948 def fqdn @fqdn end |
#gke_master_cluster ⇒ String
A cluster URI for Google Kubernetes Engine cluster control plane.
Corresponds to the JSON property gkeMasterCluster
954 955 956 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 954 def gke_master_cluster @gke_master_cluster end |
#gke_pod ⇒ String
A GKE Pod URI.
Corresponds to the JSON property gkePod
959 960 961 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 959 def gke_pod @gke_pod end |
#instance ⇒ String
A Compute Engine instance URI.
Corresponds to the JSON property instance
964 965 966 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 964 def instance @instance end |
#ip_address ⇒ String
The IP address of the endpoint, which can be an external or internal IP.
Corresponds to the JSON property ipAddress
969 970 971 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 969 def ip_address @ip_address end |
#load_balancer_id ⇒ String
Output only. ID of the load balancer the forwarding rule points to. Empty for
forwarding rules not related to load balancers.
Corresponds to the JSON property loadBalancerId
975 976 977 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 975 def load_balancer_id @load_balancer_id end |
#load_balancer_type ⇒ String
Output only. Type of the load balancer the forwarding rule points to.
Corresponds to the JSON property loadBalancerType
980 981 982 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 980 def load_balancer_type @load_balancer_type end |
#network ⇒ String
A VPC network URI. For source endpoints, used according to the network_type.
For destination endpoints, used only when the source is an external IP address
endpoint, and the destination is an internal IP address endpoint.
Corresponds to the JSON property network
987 988 989 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 987 def network @network end |
#network_type ⇒ String
For source endpoints, type of the network where the endpoint is located. Not
relevant for destination endpoints.
Corresponds to the JSON property networkType
993 994 995 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 993 def network_type @network_type end |
#port ⇒ Fixnum
The IP protocol port of the endpoint. Only applicable when protocol is TCP or
UDP.
Corresponds to the JSON property port
999 1000 1001 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 999 def port @port end |
#project_id ⇒ String
For source endpoints, endpoint project ID. Used according to the network_type
. Not relevant for destination endpoints.
Corresponds to the JSON property projectId
1005 1006 1007 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1005 def project_id @project_id end |
#redis_cluster ⇒ String
A Redis Cluster URI.
Applicable only to destination endpoint.
Corresponds to the JSON property redisCluster
1011 1012 1013 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1011 def redis_cluster @redis_cluster end |
#redis_instance ⇒ String
A Redis Instance URI.
Applicable only to destination endpoint.
Corresponds to the JSON property redisInstance
1017 1018 1019 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1017 def redis_instance @redis_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1024 def update!(**args) @app_engine_version = args[:app_engine_version] if args.key?(:app_engine_version) @cloud_function = args[:cloud_function] if args.key?(:cloud_function) @cloud_run_job = args[:cloud_run_job] if args.key?(:cloud_run_job) @cloud_run_revision = args[:cloud_run_revision] if args.key?(:cloud_run_revision) @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance) @datastream_private_connection = args[:datastream_private_connection] if args.key?(:datastream_private_connection) @dms_private_connection = args[:dms_private_connection] if args.key?(:dms_private_connection) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_target = args[:forwarding_rule_target] if args.key?(:forwarding_rule_target) @fqdn = args[:fqdn] if args.key?(:fqdn) @gke_master_cluster = args[:gke_master_cluster] if args.key?(:gke_master_cluster) @gke_pod = args[:gke_pod] if args.key?(:gke_pod) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) @network = args[:network] if args.key?(:network) @network_type = args[:network_type] if args.key?(:network_type) @port = args[:port] if args.key?(:port) @project_id = args[:project_id] if args.key?(:project_id) @redis_cluster = args[:redis_cluster] if args.key?(:redis_cluster) @redis_instance = args[:redis_instance] if args.key?(:redis_instance) end |