Class: Google::Apis::NetworkmanagementV1beta1::EndpointInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::EndpointInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.
Instance Attribute Summary collapse
-
#destination_ip ⇒ String
Destination IP address.
-
#destination_network_uri ⇒ String
URI of the network where this packet is sent to.
-
#destination_port ⇒ Fixnum
Destination port.
-
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
-
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
-
#source_ip ⇒ String
Source IP address.
-
#source_network_uri ⇒ String
URI of the network where this packet originates from.
-
#source_port ⇒ Fixnum
Source port.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndpointInfo
constructor
A new instance of EndpointInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndpointInfo
Returns a new instance of EndpointInfo.
1142 1143 1144 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_ip ⇒ String
Destination IP address.
Corresponds to the JSON property destinationIp
1103 1104 1105 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1103 def destination_ip @destination_ip end |
#destination_network_uri ⇒ String
URI of the network where this packet is sent to. Format: projects/project_id
/global/networks/network_id`
Corresponds to the JSON propertydestinationNetworkUri`
1109 1110 1111 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1109 def destination_network_uri @destination_network_uri end |
#destination_port ⇒ Fixnum
Destination port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property destinationPort
1114 1115 1116 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1114 def destination_port @destination_port end |
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
Corresponds to the JSON property protocol
1119 1120 1121 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1119 def protocol @protocol end |
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
Corresponds to the JSON property sourceAgentUri
1124 1125 1126 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1124 def source_agent_uri @source_agent_uri end |
#source_ip ⇒ String
Source IP address.
Corresponds to the JSON property sourceIp
1129 1130 1131 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1129 def source_ip @source_ip end |
#source_network_uri ⇒ String
URI of the network where this packet originates from. Format: projects/
project_id/global/networks/network_id`
Corresponds to the JSON propertysourceNetworkUri`
1135 1136 1137 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1135 def source_network_uri @source_network_uri end |
#source_port ⇒ Fixnum
Source port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property sourcePort
1140 1141 1142 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1140 def source_port @source_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1147 def update!(**args) @destination_ip = args[:destination_ip] if args.key?(:destination_ip) @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri) @destination_port = args[:destination_port] if args.key?(:destination_port) @protocol = args[:protocol] if args.key?(:protocol) @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri) @source_ip = args[:source_ip] if args.key?(:source_ip) @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri) @source_port = args[:source_port] if args.key?(:source_port) end |