Class: Google::Apis::NetworkmanagementV1beta1::EndpointInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointInfo

Returns a new instance of EndpointInfo.



1127
1128
1129
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Corresponds to the JSON property destinationIp

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1090

def destination_ip
  @destination_ip
end

#destination_network_uriString

URI of the network where this packet is sent to. Corresponds to the JSON property destinationNetworkUri

Returns:

  • (String)


1095
1096
1097
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1095

def destination_network_uri
  @destination_network_uri
end

#destination_portFixnum

Destination port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


1100
1101
1102
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1100

def destination_port
  @destination_port
end

#protocolString

IP protocol in string format, for example: "TCP", "UDP", "ICMP". Corresponds to the JSON property protocol

Returns:

  • (String)


1105
1106
1107
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1105

def protocol
  @protocol
end

#source_agent_uriString

URI of the source telemetry agent this packet originates from. Corresponds to the JSON property sourceAgentUri

Returns:

  • (String)


1110
1111
1112
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1110

def source_agent_uri
  @source_agent_uri
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


1115
1116
1117
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1115

def source_ip
  @source_ip
end

#source_network_uriString

URI of the network where this packet originates from. Corresponds to the JSON property sourceNetworkUri

Returns:

  • (String)


1120
1121
1122
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1120

def source_network_uri
  @source_network_uri
end

#source_portFixnum

Source port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


1125
1126
1127
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1125

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1132

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri)
  @source_port = args[:source_port] if args.key?(:source_port)
end