Class: Google::Apis::NetworkmanagementV1beta1::EndpointInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::EndpointInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.
Instance Attribute Summary collapse
-
#destination_ip ⇒ String
Destination IP address.
-
#destination_network_uri ⇒ String
URI of the network where this packet is sent to.
-
#destination_port ⇒ Fixnum
Destination port.
-
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
-
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
-
#source_ip ⇒ String
Source IP address.
-
#source_network_uri ⇒ String
URI of the network where this packet originates from.
-
#source_port ⇒ Fixnum
Source port.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndpointInfo
constructor
A new instance of EndpointInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndpointInfo
Returns a new instance of EndpointInfo.
1087 1088 1089 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_ip ⇒ String
Destination IP address.
Corresponds to the JSON property destinationIp
1050 1051 1052 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1050 def destination_ip @destination_ip end |
#destination_network_uri ⇒ String
URI of the network where this packet is sent to.
Corresponds to the JSON property destinationNetworkUri
1055 1056 1057 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1055 def destination_network_uri @destination_network_uri end |
#destination_port ⇒ Fixnum
Destination port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property destinationPort
1060 1061 1062 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1060 def destination_port @destination_port end |
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
Corresponds to the JSON property protocol
1065 1066 1067 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1065 def protocol @protocol end |
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
Corresponds to the JSON property sourceAgentUri
1070 1071 1072 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1070 def source_agent_uri @source_agent_uri end |
#source_ip ⇒ String
Source IP address.
Corresponds to the JSON property sourceIp
1075 1076 1077 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1075 def source_ip @source_ip end |
#source_network_uri ⇒ String
URI of the network where this packet originates from.
Corresponds to the JSON property sourceNetworkUri
1080 1081 1082 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1080 def source_network_uri @source_network_uri end |
#source_port ⇒ Fixnum
Source port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property sourcePort
1085 1086 1087 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1085 def source_port @source_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1092 def update!(**args) @destination_ip = args[:destination_ip] if args.key?(:destination_ip) @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri) @destination_port = args[:destination_port] if args.key?(:destination_port) @protocol = args[:protocol] if args.key?(:protocol) @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri) @source_ip = args[:source_ip] if args.key?(:source_ip) @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri) @source_port = args[:source_port] if args.key?(:source_port) end |