Class: Google::Apis::NetworkmanagementV1beta1::FirewallInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::FirewallInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Instance Attribute Summary collapse
-
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property
action. -
#direction ⇒ String
Possible values: INGRESS, EGRESS Corresponds to the JSON property
direction. -
#display_name ⇒ String
The display name of the firewall rule.
-
#firewall_rule_type ⇒ String
The firewall rule's type.
-
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with in format "projects/
project/global/networks/network". -
#policy ⇒ String
The name of the firewall policy that this rule is associated with.
-
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with.
-
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with.
-
#priority ⇒ Fixnum
The priority of the firewall rule.
-
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
-
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule.
-
#target_type ⇒ String
Target type of the firewall rule.
-
#uri ⇒ String
The URI of the firewall rule in format "projects/
project/global/firewalls/firewall".
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallInfo
constructor
A new instance of FirewallInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallInfo
Returns a new instance of FirewallInfo.
1295 1296 1297 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1295 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
Corresponds to the JSON property action
1221 1222 1223 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1221 def action @action end |
#direction ⇒ String
Possible values: INGRESS, EGRESS
Corresponds to the JSON property direction
1226 1227 1228 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1226 def direction @direction end |
#display_name ⇒ String
The display name of the firewall rule. This field might be empty for firewall
policy rules.
Corresponds to the JSON property displayName
1232 1233 1234 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1232 def display_name @display_name end |
#firewall_rule_type ⇒ String
The firewall rule's type.
Corresponds to the JSON property firewallRuleType
1237 1238 1239 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1237 def firewall_rule_type @firewall_rule_type end |
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with in format
"projects/project/global/networks/network". This field is not applicable
to hierarchical firewall policy rules.
Corresponds to the JSON property networkUri
1244 1245 1246 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1244 def network_uri @network_uri end |
#policy ⇒ String
The name of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policy
1250 1251 1252 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1250 def policy @policy end |
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with. This
field is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyPriority
1256 1257 1258 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1256 def policy_priority @policy_priority end |
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Format:
locations/global/firewallPolicies/policy_id(hierarchical policy) * ` projects/`project_id`/global/firewallPolicies/`policy_id(global network firewall policy) *projects/project_id/regions/region/firewallPolicies/policy_id`(regional network firewall policy) Corresponds to the JSON propertypolicyUri`
1266 1267 1268 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1266 def policy_uri @policy_uri end |
#priority ⇒ Fixnum
The priority of the firewall rule.
Corresponds to the JSON property priority
1271 1272 1273 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1271 def priority @priority end |
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
Corresponds to the JSON property targetServiceAccounts
1276 1277 1278 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1276 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule. This field is not applicable
to firewall policy rules.
Corresponds to the JSON property targetTags
1282 1283 1284 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1282 def @target_tags end |
#target_type ⇒ String
Target type of the firewall rule.
Corresponds to the JSON property targetType
1287 1288 1289 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1287 def target_type @target_type end |
#uri ⇒ String
The URI of the firewall rule in format "projects/project/global/firewalls/
firewall". This field is not applicable to implied VPC firewall rules.
Corresponds to the JSON property uri
1293 1294 1295 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1293 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1300 def update!(**args) @action = args[:action] if args.key?(:action) @direction = args[:direction] if args.key?(:direction) @display_name = args[:display_name] if args.key?(:display_name) @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type) @network_uri = args[:network_uri] if args.key?(:network_uri) @policy = args[:policy] if args.key?(:policy) @policy_priority = args[:policy_priority] if args.key?(:policy_priority) @policy_uri = args[:policy_uri] if args.key?(:policy_uri) @priority = args[:priority] if args.key?(:priority) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) @target_type = args[:target_type] if args.key?(:target_type) @uri = args[:uri] if args.key?(:uri) end |