Class: Google::Apis::NetworkmanagementV1beta1::FirewallInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallInfo

Returns a new instance of FirewallInfo.



1275
1276
1277
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property action

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1206

def action
  @action
end

#directionString

Possible values: INGRESS, EGRESS Corresponds to the JSON property direction

Returns:

  • (String)


1211
1212
1213
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1211

def direction
  @direction
end

#display_nameString

The display name of the firewall rule. This field might be empty for firewall policy rules. Corresponds to the JSON property displayName

Returns:

  • (String)


1217
1218
1219
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1217

def display_name
  @display_name
end

#firewall_rule_typeString

The firewall rule's type. Corresponds to the JSON property firewallRuleType

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1222

def firewall_rule_type
  @firewall_rule_type
end

#network_uriString

The URI of the VPC network that the firewall rule is associated with. This field is not applicable to hierarchical firewall policy rules. Corresponds to the JSON property networkUri

Returns:

  • (String)


1228
1229
1230
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1228

def network_uri
  @network_uri
end

#policyString

The name of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policy

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1234

def policy
  @policy
end

#policy_priorityFixnum

The priority of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policyPriority

Returns:

  • (Fixnum)


1240
1241
1242
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1240

def policy_priority
  @policy_priority
end

#policy_uriString

The URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policyUri

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1246

def policy_uri
  @policy_uri
end

#priorityFixnum

The priority of the firewall rule. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1251
1252
1253
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1251

def priority
  @priority
end

#target_service_accountsArray<String>

The target service accounts specified by the firewall rule. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


1256
1257
1258
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1256

def target_service_accounts
  @target_service_accounts
end

#target_tagsArray<String>

The target tags defined by the VPC firewall rule. This field is not applicable to firewall policy rules. Corresponds to the JSON property targetTags

Returns:

  • (Array<String>)


1262
1263
1264
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1262

def target_tags
  @target_tags
end

#target_typeString

Target type of the firewall rule. Corresponds to the JSON property targetType

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1267

def target_type
  @target_type
end

#uriString

The URI of the firewall rule. This field is not applicable to implied VPC firewall rules. Corresponds to the JSON property uri

Returns:

  • (String)


1273
1274
1275
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1273

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1280

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @direction = args[:direction] if args.key?(:direction)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @policy = args[:policy] if args.key?(:policy)
  @policy_priority = args[:policy_priority] if args.key?(:policy_priority)
  @policy_uri = args[:policy_uri] if args.key?(:policy_uri)
  @priority = args[:priority] if args.key?(:priority)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_tags = args[:target_tags] if args.key?(:target_tags)
  @target_type = args[:target_type] if args.key?(:target_type)
  @uri = args[:uri] if args.key?(:uri)
end