Class: Google::Apis::NetworkmanagementV1beta1::FirewallInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::FirewallInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Instance Attribute Summary collapse
-
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property
action. -
#direction ⇒ String
Possible values: INGRESS, EGRESS Corresponds to the JSON property
direction. -
#display_name ⇒ String
The display name of the firewall rule.
-
#firewall_rule_type ⇒ String
The firewall rule's type.
-
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with.
-
#policy ⇒ String
The name of the firewall policy that this rule is associated with.
-
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with.
-
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with.
-
#priority ⇒ Fixnum
The priority of the firewall rule.
-
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
-
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule.
-
#target_type ⇒ String
Target type of the firewall rule.
-
#uri ⇒ String
The URI of the firewall rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallInfo
constructor
A new instance of FirewallInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallInfo
Returns a new instance of FirewallInfo.
1244 1245 1246 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
Corresponds to the JSON property action
1175 1176 1177 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1175 def action @action end |
#direction ⇒ String
Possible values: INGRESS, EGRESS
Corresponds to the JSON property direction
1180 1181 1182 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1180 def direction @direction end |
#display_name ⇒ String
The display name of the firewall rule. This field might be empty for firewall
policy rules.
Corresponds to the JSON property displayName
1186 1187 1188 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1186 def display_name @display_name end |
#firewall_rule_type ⇒ String
The firewall rule's type.
Corresponds to the JSON property firewallRuleType
1191 1192 1193 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1191 def firewall_rule_type @firewall_rule_type end |
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with. This
field is not applicable to hierarchical firewall policy rules.
Corresponds to the JSON property networkUri
1197 1198 1199 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1197 def network_uri @network_uri end |
#policy ⇒ String
The name of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policy
1203 1204 1205 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1203 def policy @policy end |
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with. This
field is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyPriority
1209 1210 1211 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1209 def policy_priority @policy_priority end |
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyUri
1215 1216 1217 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1215 def policy_uri @policy_uri end |
#priority ⇒ Fixnum
The priority of the firewall rule.
Corresponds to the JSON property priority
1220 1221 1222 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1220 def priority @priority end |
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
Corresponds to the JSON property targetServiceAccounts
1225 1226 1227 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1225 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule. This field is not applicable
to firewall policy rules.
Corresponds to the JSON property targetTags
1231 1232 1233 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1231 def @target_tags end |
#target_type ⇒ String
Target type of the firewall rule.
Corresponds to the JSON property targetType
1236 1237 1238 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1236 def target_type @target_type end |
#uri ⇒ String
The URI of the firewall rule. This field is not applicable to implied VPC
firewall rules.
Corresponds to the JSON property uri
1242 1243 1244 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1242 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1249 def update!(**args) @action = args[:action] if args.key?(:action) @direction = args[:direction] if args.key?(:direction) @display_name = args[:display_name] if args.key?(:display_name) @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type) @network_uri = args[:network_uri] if args.key?(:network_uri) @policy = args[:policy] if args.key?(:policy) @policy_priority = args[:policy_priority] if args.key?(:policy_priority) @policy_uri = args[:policy_uri] if args.key?(:policy_uri) @priority = args[:priority] if args.key?(:priority) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) @target_type = args[:target_type] if args.key?(:target_type) @uri = args[:uri] if args.key?(:uri) end |