Class: Google::Apis::NetworkmanagementV1beta1::ForwardingRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine forwarding rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleInfo

Returns a new instance of ForwardingRuleInfo.



1415
1416
1417
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of the forwarding rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1357

def display_name
  @display_name
end

#load_balancer_nameString

Name of the load balancer the forwarding rule belongs to. Empty for forwarding rules not related to load balancers (like PSC forwarding rules). Corresponds to the JSON property loadBalancerName

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1363

def load_balancer_name
  @load_balancer_name
end

#matched_port_rangeString

Port range defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedPortRange

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1368

def matched_port_range
  @matched_port_range
end

#matched_protocolString

Protocol defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedProtocol

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1373

def matched_protocol
  @matched_protocol
end

#network_uriString

URI of a VPC network where the forwarding rule is located in format "projects/ project/global/networks/network". Corresponds to the JSON property networkUri

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1379

def network_uri
  @network_uri
end

#psc_google_api_targetString

PSC Google API target this forwarding rule targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


1384
1385
1386
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1384

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this forwarding rule targets (if applicable) in format "projects/project/regions/region/serviceAttachments/ service_attachment". Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1391

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

#regionString

Region of the forwarding rule. Set only for regional forwarding rules. Corresponds to the JSON property region

Returns:

  • (String)


1396
1397
1398
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1396

def region
  @region
end

#targetString

Target type of the forwarding rule. Corresponds to the JSON property target

Returns:

  • (String)


1401
1402
1403
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1401

def target
  @target
end

#uriString

URI of the forwarding rule in format "projects/project/global/ forwardingRules/forwarding_rule" (global) or "projects/project/regions/ region/forwardingRules/forwarding_rule" (regional). Corresponds to the JSON property uri

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1408

def uri
  @uri
end

#vipString

VIP of the forwarding rule. Corresponds to the JSON property vip

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1413

def vip
  @vip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1420

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @load_balancer_name = args[:load_balancer_name] if args.key?(:load_balancer_name)
  @matched_port_range = args[:matched_port_range] if args.key?(:matched_port_range)
  @matched_protocol = args[:matched_protocol] if args.key?(:matched_protocol)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
  @region = args[:region] if args.key?(:region)
  @target = args[:target] if args.key?(:target)
  @uri = args[:uri] if args.key?(:uri)
  @vip = args[:vip] if args.key?(:vip)
end