Class: Google::Apis::NetworkmanagementV1beta1::ForwardingRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine forwarding rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleInfo

Returns a new instance of ForwardingRuleInfo.



1357
1358
1359
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of the forwarding rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1304
1305
1306
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1304

def display_name
  @display_name
end

#load_balancer_nameString

Name of the load balancer the forwarding rule belongs to. Empty for forwarding rules not related to load balancers (like PSC forwarding rules). Corresponds to the JSON property loadBalancerName

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1310

def load_balancer_name
  @load_balancer_name
end

#matched_port_rangeString

Port range defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedPortRange

Returns:

  • (String)


1315
1316
1317
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1315

def matched_port_range
  @matched_port_range
end

#matched_protocolString

Protocol defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedProtocol

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1320

def matched_protocol
  @matched_protocol
end

#network_uriString

Network URI. Corresponds to the JSON property networkUri

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1325

def network_uri
  @network_uri
end

#psc_google_api_targetString

PSC Google API target this forwarding rule targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


1330
1331
1332
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1330

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this forwarding rule targets (if applicable). Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


1335
1336
1337
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1335

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

#regionString

Region of the forwarding rule. Set only for regional forwarding rules. Corresponds to the JSON property region

Returns:

  • (String)


1340
1341
1342
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1340

def region
  @region
end

#targetString

Target type of the forwarding rule. Corresponds to the JSON property target

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1345

def target
  @target
end

#uriString

URI of the forwarding rule. Corresponds to the JSON property uri

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1350

def uri
  @uri
end

#vipString

VIP of the forwarding rule. Corresponds to the JSON property vip

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1355

def vip
  @vip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1362

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @load_balancer_name = args[:load_balancer_name] if args.key?(:load_balancer_name)
  @matched_port_range = args[:matched_port_range] if args.key?(:matched_port_range)
  @matched_protocol = args[:matched_protocol] if args.key?(:matched_protocol)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
  @region = args[:region] if args.key?(:region)
  @target = args[:target] if args.key?(:target)
  @uri = args[:uri] if args.key?(:uri)
  @vip = args[:vip] if args.key?(:vip)
end