Class: Google::Apis::NetworkmanagementV1beta1::ForwardingRuleInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::ForwardingRuleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine forwarding rule.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of the forwarding rule.
-
#load_balancer_name ⇒ String
Name of the load balancer the forwarding rule belongs to.
-
#matched_port_range ⇒ String
Port range defined in the forwarding rule that matches the packet.
-
#matched_protocol ⇒ String
Protocol defined in the forwarding rule that matches the packet.
-
#network_uri ⇒ String
Network URI.
-
#psc_google_api_target ⇒ String
PSC Google API target this forwarding rule targets (if applicable).
-
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this forwarding rule targets (if applicable).
-
#region ⇒ String
Region of the forwarding rule.
-
#target ⇒ String
Target type of the forwarding rule.
-
#uri ⇒ String
URI of the forwarding rule.
-
#vip ⇒ String
VIP of the forwarding rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleInfo
constructor
A new instance of ForwardingRuleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleInfo
Returns a new instance of ForwardingRuleInfo.
1348 1349 1350 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of the forwarding rule.
Corresponds to the JSON property displayName
1295 1296 1297 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1295 def display_name @display_name end |
#load_balancer_name ⇒ String
Name of the load balancer the forwarding rule belongs to. Empty for forwarding
rules not related to load balancers (like PSC forwarding rules).
Corresponds to the JSON property loadBalancerName
1301 1302 1303 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1301 def load_balancer_name @load_balancer_name end |
#matched_port_range ⇒ String
Port range defined in the forwarding rule that matches the packet.
Corresponds to the JSON property matchedPortRange
1306 1307 1308 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1306 def matched_port_range @matched_port_range end |
#matched_protocol ⇒ String
Protocol defined in the forwarding rule that matches the packet.
Corresponds to the JSON property matchedProtocol
1311 1312 1313 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1311 def matched_protocol @matched_protocol end |
#network_uri ⇒ String
Network URI.
Corresponds to the JSON property networkUri
1316 1317 1318 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1316 def network_uri @network_uri end |
#psc_google_api_target ⇒ String
PSC Google API target this forwarding rule targets (if applicable).
Corresponds to the JSON property pscGoogleApiTarget
1321 1322 1323 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1321 def psc_google_api_target @psc_google_api_target end |
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this forwarding rule targets (if applicable).
Corresponds to the JSON property pscServiceAttachmentUri
1326 1327 1328 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1326 def @psc_service_attachment_uri end |
#region ⇒ String
Region of the forwarding rule. Set only for regional forwarding rules.
Corresponds to the JSON property region
1331 1332 1333 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1331 def region @region end |
#target ⇒ String
Target type of the forwarding rule.
Corresponds to the JSON property target
1336 1337 1338 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1336 def target @target end |
#uri ⇒ String
URI of the forwarding rule.
Corresponds to the JSON property uri
1341 1342 1343 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1341 def uri @uri end |
#vip ⇒ String
VIP of the forwarding rule.
Corresponds to the JSON property vip
1346 1347 1348 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1346 def vip @vip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1353 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @load_balancer_name = args[:load_balancer_name] if args.key?(:load_balancer_name) @matched_port_range = args[:matched_port_range] if args.key?(:matched_port_range) @matched_protocol = args[:matched_protocol] if args.key?(:matched_protocol) @network_uri = args[:network_uri] if args.key?(:network_uri) @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target) @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri) @region = args[:region] if args.key?(:region) @target = args[:target] if args.key?(:target) @uri = args[:uri] if args.key?(:uri) @vip = args[:vip] if args.key?(:vip) end |