Class: Google::Apis::NetworkmanagementV1beta1::GkeNetworkPolicyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a GKE Network Policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeNetworkPolicyInfo

Returns a new instance of GkeNetworkPolicyInfo.



1448
1449
1450
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Possible values: ALLOW, DENY Corresponds to the JSON property action

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1428

def action
  @action
end

#directionString

Possible values: INGRESS, EGRESS Corresponds to the JSON property direction

Returns:

  • (String)


1433
1434
1435
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1433

def direction
  @direction
end

#display_nameString

The name of the Network Policy. Corresponds to the JSON property displayName

Returns:

  • (String)


1438
1439
1440
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1438

def display_name
  @display_name
end

#uriString

The URI of the Network Policy. Format for a Network Policy in a zonal cluster: projects//zones//clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Format for a Network Policy in a regional cluster: projects//locations// clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Corresponds to the JSON property uri

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1446

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1453
1454
1455
1456
1457
1458
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1453

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @direction = args[:direction] if args.key?(:direction)
  @display_name = args[:display_name] if args.key?(:display_name)
  @uri = args[:uri] if args.key?(:uri)
end