Class: Google::Apis::NetworkmanagementV1beta1::GkeNetworkPolicyInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::GkeNetworkPolicyInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a GKE Network Policy.
Instance Attribute Summary collapse
-
#action ⇒ String
Possible values: ALLOW, DENY Corresponds to the JSON property
action. -
#direction ⇒ String
Possible values: INGRESS, EGRESS Corresponds to the JSON property
direction. -
#display_name ⇒ String
The name of the Network Policy.
-
#uri ⇒ String
The URI of the Network Policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeNetworkPolicyInfo
constructor
A new instance of GkeNetworkPolicyInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeNetworkPolicyInfo
Returns a new instance of GkeNetworkPolicyInfo.
1439 1440 1441 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Possible values: ALLOW, DENY
Corresponds to the JSON property action
1419 1420 1421 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1419 def action @action end |
#direction ⇒ String
Possible values: INGRESS, EGRESS
Corresponds to the JSON property direction
1424 1425 1426 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1424 def direction @direction end |
#display_name ⇒ String
The name of the Network Policy.
Corresponds to the JSON property displayName
1429 1430 1431 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1429 def display_name @display_name end |
#uri ⇒ String
The URI of the Network Policy. Format for a Network Policy in a zonal cluster:
projects//zones//clusters//k8s/namespaces//networking.k8s.io/networkpolicies/
Format for a Network Policy in a regional cluster: projects//locations//
clusters//k8s/namespaces//networking.k8s.io/networkpolicies/
Corresponds to the JSON property uri
1437 1438 1439 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1437 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1444 1445 1446 1447 1448 1449 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1444 def update!(**args) @action = args[:action] if args.key?(:action) @direction = args[:direction] if args.key?(:direction) @display_name = args[:display_name] if args.key?(:display_name) @uri = args[:uri] if args.key?(:uri) end |