Class: Google::Apis::NetworkmanagementV1beta1::InstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::InstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine instance.
-
#external_ip ⇒ String
External IP address of the network interface.
-
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
-
#internal_ip ⇒ String
Internal IP address of the network interface.
-
#network_tags ⇒ Array<String>
Network tags configured on the instance.
-
#network_uri ⇒ String
URI of a Compute Engine network in format "projects/
project/global/networks/network" Corresponds to the JSON propertynetworkUri. -
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant) in format "projects/
project/regions/region/networkAttachments/network_attachment" Corresponds to the JSON propertypscNetworkAttachmentUri. -
#running ⇒ Boolean
(also: #running?)
Indicates whether the Compute Engine instance is running.
-
#service_account ⇒ String
Service account authorized for the instance.
-
#status ⇒ String
The status of the instance.
-
#uri ⇒ String
URI of a Compute Engine instance in format "projects/
project/zones/zone/ instances/instance" Corresponds to the JSON propertyuri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceInfo
constructor
A new instance of InstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceInfo
Returns a new instance of InstanceInfo.
1705 1706 1707 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine instance.
Corresponds to the JSON property displayName
1647 1648 1649 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1647 def display_name @display_name end |
#external_ip ⇒ String
External IP address of the network interface.
Corresponds to the JSON property externalIp
1652 1653 1654 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1652 def external_ip @external_ip end |
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
Corresponds to the JSON property interface
1657 1658 1659 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1657 def interface @interface end |
#internal_ip ⇒ String
Internal IP address of the network interface.
Corresponds to the JSON property internalIp
1662 1663 1664 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1662 def internal_ip @internal_ip end |
#network_tags ⇒ Array<String>
Network tags configured on the instance.
Corresponds to the JSON property networkTags
1667 1668 1669 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1667 def @network_tags end |
#network_uri ⇒ String
URI of a Compute Engine network in format "projects/project/global/networks/
network"
Corresponds to the JSON property networkUri
1673 1674 1675 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1673 def network_uri @network_uri end |
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant) in
format "projects/project/regions/region/networkAttachments/
network_attachment"
Corresponds to the JSON property pscNetworkAttachmentUri
1680 1681 1682 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1680 def @psc_network_attachment_uri end |
#running ⇒ Boolean Also known as: running?
Indicates whether the Compute Engine instance is running. Deprecated: use the
status field instead.
Corresponds to the JSON property running
1686 1687 1688 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1686 def running @running end |
#service_account ⇒ String
Service account authorized for the instance.
Corresponds to the JSON property serviceAccount
1692 1693 1694 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1692 def service_account @service_account end |
#status ⇒ String
The status of the instance.
Corresponds to the JSON property status
1697 1698 1699 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1697 def status @status end |
#uri ⇒ String
URI of a Compute Engine instance in format "projects/project/zones/zone/
instances/instance"
Corresponds to the JSON property uri
1703 1704 1705 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1703 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1710 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @external_ip = args[:external_ip] if args.key?(:external_ip) @interface = args[:interface] if args.key?(:interface) @internal_ip = args[:internal_ip] if args.key?(:internal_ip) @network_tags = args[:network_tags] if args.key?(:network_tags) @network_uri = args[:network_uri] if args.key?(:network_uri) @psc_network_attachment_uri = args[:psc_network_attachment_uri] if args.key?(:psc_network_attachment_uri) @running = args[:running] if args.key?(:running) @service_account = args[:service_account] if args.key?(:service_account) @status = args[:status] if args.key?(:status) @uri = args[:uri] if args.key?(:uri) end |