Class: Google::Apis::NetworkmanagementV1beta1::InterconnectAttachmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::InterconnectAttachmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with an Interconnect attachment.
Instance Attribute Summary collapse
-
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing.
-
#display_name ⇒ String
Name of an Interconnect attachment.
-
#interconnect_uri ⇒ String
URI of the Interconnect.
-
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
-
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
-
#type ⇒ String
The type of interconnect attachment this is.
-
#uri ⇒ String
URI of the Interconnect attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentInfo
constructor
A new instance of InterconnectAttachmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentInfo
Returns a new instance of InterconnectAttachmentInfo.
1767 1768 1769 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing. Format: projects/
project_id/regions/region/routers/router_id`
Corresponds to the JSON propertycloudRouterUri`
1733 1734 1735 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1733 def cloud_router_uri @cloud_router_uri end |
#display_name ⇒ String
Name of an Interconnect attachment.
Corresponds to the JSON property displayName
1738 1739 1740 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1738 def display_name @display_name end |
#interconnect_uri ⇒ String
URI of the Interconnect. Format: projects/project_id/global/interconnects/
interconnect_id`
Corresponds to the JSON propertyinterconnectUri`
1744 1745 1746 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1744 def interconnect_uri @interconnect_uri end |
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
Corresponds to the JSON property l2AttachmentMatchedIpAddress
1749 1750 1751 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1749 def @l2_attachment_matched_ip_address end |
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
Corresponds to the JSON property region
1754 1755 1756 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1754 def region @region end |
#type ⇒ String
The type of interconnect attachment this is.
Corresponds to the JSON property type
1759 1760 1761 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1759 def type @type end |
#uri ⇒ String
URI of the Interconnect attachment. Format: projects/project_id/regions/
region/interconnectAttachments/attachment_id`
Corresponds to the JSON propertyuri`
1765 1766 1767 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1765 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1772 1773 1774 1775 1776 1777 1778 1779 1780 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1772 def update!(**args) @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri) @display_name = args[:display_name] if args.key?(:display_name) @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri) @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address) @region = args[:region] if args.key?(:region) @type = args[:type] if args.key?(:type) @uri = args[:uri] if args.key?(:uri) end |