Class: Google::Apis::NetworkmanagementV1beta1::InterconnectAttachmentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with an Interconnect attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentInfo

Returns a new instance of InterconnectAttachmentInfo.



1688
1689
1690
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_router_uriString

URI of the Cloud Router to be used for dynamic routing. Corresponds to the JSON property cloudRouterUri

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1656

def cloud_router_uri
  @cloud_router_uri
end

#display_nameString

Name of an Interconnect attachment. Corresponds to the JSON property displayName

Returns:

  • (String)


1661
1662
1663
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1661

def display_name
  @display_name
end

#interconnect_uriString

URI of the Interconnect where the Interconnect attachment is configured. Corresponds to the JSON property interconnectUri

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1666

def interconnect_uri
  @interconnect_uri
end

#l2_attachment_matched_ip_addressString

Appliance IP address that was matched for L2_DEDICATED attachments. Corresponds to the JSON property l2AttachmentMatchedIpAddress

Returns:

  • (String)


1671
1672
1673
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1671

def l2_attachment_matched_ip_address
  @l2_attachment_matched_ip_address
end

#regionString

Name of a Google Cloud region where the Interconnect attachment is configured. Corresponds to the JSON property region

Returns:

  • (String)


1676
1677
1678
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1676

def region
  @region
end

#typeString

The type of interconnect attachment this is. Corresponds to the JSON property type

Returns:

  • (String)


1681
1682
1683
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1681

def type
  @type
end

#uriString

URI of an Interconnect attachment. Corresponds to the JSON property uri

Returns:

  • (String)


1686
1687
1688
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1686

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1693
1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1693

def update!(**args)
  @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri)
  @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address)
  @region = args[:region] if args.key?(:region)
  @type = args[:type] if args.key?(:type)
  @uri = args[:uri] if args.key?(:uri)
end