Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with the load balancer backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerBackendInfo

Returns a new instance of LoadBalancerBackendInfo.



2102
2103
2104
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucket_uriString

URI of the backend bucket this backend targets (if applicable) in format " projects/project/global/backendBuckets/backend_bucket". Corresponds to the JSON property backendBucketUri

Returns:

  • (String)


2033
2034
2035
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2033

def backend_bucket_uri
  @backend_bucket_uri
end

#backend_service_uriString

URI of the backend service this backend belongs to (if applicable) in format " projects/project/regions/region/backendServices/backend_service" ( regional) or "projects/project/global/backendServices/backend_service" ( global). Corresponds to the JSON property backendServiceUri

Returns:

  • (String)


2041
2042
2043
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2041

def backend_service_uri
  @backend_service_uri
end

#health_check_firewalls_config_stateString

Output only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load- balancing/docs/firewall-rules Corresponds to the JSON property healthCheckFirewallsConfigState

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2051

def health_check_firewalls_config_state
  @health_check_firewalls_config_state
end

#health_check_uriString

URI of the health check attached to this backend (if applicable). Format: * projects/project_id/global/healthChecks/health_check_id* `projects/` project_id`/regions/`region`/healthChecks/`health_check_id * projects/ project_id/global/httpHealthChecks/health_check_id`(legacy) Corresponds to the JSON propertyhealthCheckUri`

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2059

def health_check_uri
  @health_check_uri
end

#instance_group_uriString

URI of the instance group this backend belongs to (if applicable) in format " projects/project/zones/zone/instanceGroups/instance_group". Corresponds to the JSON property instanceGroupUri

Returns:

  • (String)


2065
2066
2067
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2065

def instance_group_uri
  @instance_group_uri
end

#instance_uriString

URI of the backend instance (if applicable) in format "projects/project/ zones/zone/instances/instance". Populated for instance group backends, and zonal NEG backends. Corresponds to the JSON property instanceUri

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2072

def instance_uri
  @instance_uri
end

#nameString

Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends. Corresponds to the JSON property name

Returns:

  • (String)


2079
2080
2081
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2079

def name
  @name
end

#network_endpoint_group_uriString

URI of the network endpoint group this backend belongs to (if applicable) Format: * projects/project_id/zones/zone/networkEndpointGroups/neg_id( zonal NEG) * `projects/`project_id`/regions/`region`/networkEndpointGroups/` neg_id (regional NEG) * projects/project_id/global/networkEndpointGroups/ neg_id`(global NEG) Corresponds to the JSON propertynetworkEndpointGroupUri`

Returns:

  • (String)


2088
2089
2090
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2088

def network_endpoint_group_uri
  @network_endpoint_group_uri
end

#psc_google_api_targetString

PSC Google API target this PSC NEG backend targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2093

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this PSC NEG backend targets (if applicable) in format "projects/project/regions/region/serviceAttachments/ service_attachment". Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2100

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2107

def update!(**args)
  @backend_bucket_uri = args[:backend_bucket_uri] if args.key?(:backend_bucket_uri)
  @backend_service_uri = args[:backend_service_uri] if args.key?(:backend_service_uri)
  @health_check_firewalls_config_state = args[:health_check_firewalls_config_state] if args.key?(:health_check_firewalls_config_state)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @instance_group_uri = args[:instance_group_uri] if args.key?(:instance_group_uri)
  @instance_uri = args[:instance_uri] if args.key?(:instance_uri)
  @name = args[:name] if args.key?(:name)
  @network_endpoint_group_uri = args[:network_endpoint_group_uri] if args.key?(:network_endpoint_group_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
end