Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with the load balancer backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerBackendInfo

Returns a new instance of LoadBalancerBackendInfo.



2003
2004
2005
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucket_uriString

URI of the backend bucket this backend targets (if applicable). Corresponds to the JSON property backendBucketUri

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1948

def backend_bucket_uri
  @backend_bucket_uri
end

#backend_service_uriString

URI of the backend service this backend belongs to (if applicable). Corresponds to the JSON property backendServiceUri

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1953

def backend_service_uri
  @backend_service_uri
end

#health_check_firewalls_config_stateString

Output only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load- balancing/docs/firewall-rules Corresponds to the JSON property healthCheckFirewallsConfigState

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1963

def health_check_firewalls_config_state
  @health_check_firewalls_config_state
end

#health_check_uriString

URI of the health check attached to this backend (if applicable). Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1968

def health_check_uri
  @health_check_uri
end

#instance_group_uriString

URI of the instance group this backend belongs to (if applicable). Corresponds to the JSON property instanceGroupUri

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1973

def instance_group_uri
  @instance_group_uri
end

#instance_uriString

URI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends. Corresponds to the JSON property instanceUri

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1979

def instance_uri
  @instance_uri
end

#nameString

Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends. Corresponds to the JSON property name

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1986

def name
  @name
end

#network_endpoint_group_uriString

URI of the network endpoint group this backend belongs to (if applicable). Corresponds to the JSON property networkEndpointGroupUri

Returns:

  • (String)


1991
1992
1993
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1991

def network_endpoint_group_uri
  @network_endpoint_group_uri
end

#psc_google_api_targetString

PSC Google API target this PSC NEG backend targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


1996
1997
1998
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1996

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this PSC NEG backend targets (if applicable). Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


2001
2002
2003
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2001

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2008

def update!(**args)
  @backend_bucket_uri = args[:backend_bucket_uri] if args.key?(:backend_bucket_uri)
  @backend_service_uri = args[:backend_service_uri] if args.key?(:backend_service_uri)
  @health_check_firewalls_config_state = args[:health_check_firewalls_config_state] if args.key?(:health_check_firewalls_config_state)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @instance_group_uri = args[:instance_group_uri] if args.key?(:instance_group_uri)
  @instance_uri = args[:instance_uri] if args.key?(:instance_uri)
  @name = args[:name] if args.key?(:name)
  @network_endpoint_group_uri = args[:network_endpoint_group_uri] if args.key?(:network_endpoint_group_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
end