Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a load balancer.
Instance Attribute Summary collapse
-
#backend_type ⇒ String
Type of load balancer's backend configuration.
-
#backend_uri ⇒ String
URI of the backend associated with the load balancer.
-
#backends ⇒ Array<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>
Information for the loadbalancer backends.
-
#health_check_uri ⇒ String
URI of the health check for the load balancer.
-
#load_balancer_type ⇒ String
Type of the load balancer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerInfo
constructor
A new instance of LoadBalancerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerInfo
Returns a new instance of LoadBalancerInfo.
2166 2167 2168 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_type ⇒ String
Type of load balancer's backend configuration.
Corresponds to the JSON property backendType
2138 2139 2140 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2138 def backend_type @backend_type end |
#backend_uri ⇒ String
URI of the backend associated with the load balancer. Format: * projects/
project_id/regions/region/backendServices/backend_service_id* `projects/
`project_id`/global/backendServices/`backend_service_id * projects/
project_id/regions/region/targetPools/target_pool_id* `projects/`
project_id`/zones/`zone`/targetInstances/`target_instance_id
Corresponds to the JSON property backendUri
2147 2148 2149 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2147 def backend_uri @backend_uri end |
#backends ⇒ Array<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>
Information for the loadbalancer backends.
Corresponds to the JSON property backends
2152 2153 2154 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2152 def backends @backends end |
#health_check_uri ⇒ String
URI of the health check for the load balancer. Deprecated and no longer
populated as different load balancer backends might have different health
checks.
Corresponds to the JSON property healthCheckUri
2159 2160 2161 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2159 def health_check_uri @health_check_uri end |
#load_balancer_type ⇒ String
Type of the load balancer.
Corresponds to the JSON property loadBalancerType
2164 2165 2166 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2164 def load_balancer_type @load_balancer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2171 def update!(**args) @backend_type = args[:backend_type] if args.key?(:backend_type) @backend_uri = args[:backend_uri] if args.key?(:backend_uri) @backends = args[:backends] if args.key?(:backends) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) end |