Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a load balancer.
Instance Attribute Summary collapse
-
#backend_type ⇒ String
Type of load balancer's backend configuration.
-
#backend_uri ⇒ String
URI of the backend associated with the load balancer.
-
#backends ⇒ Array<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>
Information for the loadbalancer backends.
-
#health_check_uri ⇒ String
URI of the health check for the load balancer.
-
#load_balancer_type ⇒ String
Type of the load balancer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerInfo
constructor
A new instance of LoadBalancerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerInfo
Returns a new instance of LoadBalancerInfo.
2156 2157 2158 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_type ⇒ String
Type of load balancer's backend configuration.
Corresponds to the JSON property backendType
2128 2129 2130 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2128 def backend_type @backend_type end |
#backend_uri ⇒ String
URI of the backend associated with the load balancer. Format: * projects/
project_id/regions/region/backendServices/backend_service_id* `projects/
`project_id`/global/backendServices/`backend_service_id * projects/
project_id/regions/region/targetPools/target_pool_id* `projects/`
project_id`/zones/`zone`/targetInstances/`target_instance_id
Corresponds to the JSON property backendUri
2137 2138 2139 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2137 def backend_uri @backend_uri end |
#backends ⇒ Array<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>
Information for the loadbalancer backends.
Corresponds to the JSON property backends
2142 2143 2144 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2142 def backends @backends end |
#health_check_uri ⇒ String
URI of the health check for the load balancer. Deprecated and no longer
populated as different load balancer backends might have different health
checks.
Corresponds to the JSON property healthCheckUri
2149 2150 2151 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2149 def health_check_uri @health_check_uri end |
#load_balancer_type ⇒ String
Type of the load balancer.
Corresponds to the JSON property loadBalancerType
2154 2155 2156 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2154 def load_balancer_type @load_balancer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2161 2162 2163 2164 2165 2166 2167 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2161 def update!(**args) @backend_type = args[:backend_type] if args.key?(:backend_type) @backend_uri = args[:backend_uri] if args.key?(:backend_uri) @backends = args[:backends] if args.key?(:backends) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) end |