Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



2062
2063
2064
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


2038
2039
2040
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2038

def backend_type
  @backend_type
end

#backend_uriString

Backend configuration URI. Corresponds to the JSON property backendUri

Returns:

  • (String)


2043
2044
2045
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2043

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



2048
2049
2050
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2048

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


2055
2056
2057
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2055

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2060
2061
2062
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2060

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2067
2068
2069
2070
2071
2072
2073
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2067

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end