Class: Google::Apis::NetworkmanagementV1beta1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



1922
1923
1924
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


1898
1899
1900
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1898

def backend_type
  @backend_type
end

#backend_uriString

Backend configuration URI. Corresponds to the JSON property backendUri

Returns:

  • (String)


1903
1904
1905
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1903

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1beta1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



1908
1909
1910
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1908

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


1915
1916
1917
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1915

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1920

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1927
1928
1929
1930
1931
1932
1933
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 1927

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end