Class: Google::Apis::NetworkmanagementV1beta1::NetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInfo

Returns a new instance of NetworkInfo.



2250
2251
2252
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine network. Corresponds to the JSON property displayName

Returns:

  • (String)


2228
2229
2230
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2228

def display_name
  @display_name
end

#matched_ip_rangeString

The IP range of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedIpRange

Returns:

  • (String)


2233
2234
2235
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2233

def matched_ip_range
  @matched_ip_range
end

#matched_subnet_uriString

URI of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedSubnetUri

Returns:

  • (String)


2238
2239
2240
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2238

def matched_subnet_uri
  @matched_subnet_uri
end

#regionString

The region of the subnet matching the source IP address of the test. Corresponds to the JSON property region

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2243

def region
  @region
end

#uriString

URI of a Compute Engine network. Corresponds to the JSON property uri

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2248

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2255
2256
2257
2258
2259
2260
2261
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2255

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range)
  @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end