Class: Google::Apis::NetworkmanagementV1beta1::NetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInfo

Returns a new instance of NetworkInfo.



2110
2111
2112
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine network. Corresponds to the JSON property displayName

Returns:

  • (String)


2088
2089
2090
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2088

def display_name
  @display_name
end

#matched_ip_rangeString

The IP range of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedIpRange

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2093

def matched_ip_range
  @matched_ip_range
end

#matched_subnet_uriString

URI of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedSubnetUri

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2098

def matched_subnet_uri
  @matched_subnet_uri
end

#regionString

The region of the subnet matching the source IP address of the test. Corresponds to the JSON property region

Returns:

  • (String)


2103
2104
2105
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2103

def region
  @region
end

#uriString

URI of a Compute Engine network. Corresponds to the JSON property uri

Returns:

  • (String)


2108
2109
2110
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2108

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2115
2116
2117
2118
2119
2120
2121
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2115

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range)
  @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end