Class: Google::Apis::NetworkmanagementV1beta1::ProbingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Results of active probing from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProbingDetails

Returns a new instance of ProbingDetails.



2578
2579
2580
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abort_causeString

The reason probing was aborted. Corresponds to the JSON property abortCause

Returns:

  • (String)


2517
2518
2519
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2517

def abort_cause
  @abort_cause
end

#destination_egress_locationGoogle::Apis::NetworkmanagementV1beta1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



2523
2524
2525
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2523

def destination_egress_location
  @destination_egress_location
end

#edge_responsesArray<Google::Apis::NetworkmanagementV1beta1::SingleEdgeResponse>

Probing results for all edge devices. Corresponds to the JSON property edgeResponses



2528
2529
2530
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2528

def edge_responses
  @edge_responses
end

#endpoint_infoGoogle::Apis::NetworkmanagementV1beta1::EndpointInfo

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model. Corresponds to the JSON property endpointInfo



2535
2536
2537
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2535

def endpoint_info
  @endpoint_info
end

#errorGoogle::Apis::NetworkmanagementV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2545
2546
2547
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2545

def error
  @error
end

#probed_all_devicesBoolean Also known as: probed_all_devices?

Whether all relevant edge devices were probed. Corresponds to the JSON property probedAllDevices

Returns:

  • (Boolean)


2550
2551
2552
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2550

def probed_all_devices
  @probed_all_devices
end

#probing_latencyGoogle::Apis::NetworkmanagementV1beta1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



2556
2557
2558
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2556

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing. Corresponds to the JSON property result

Returns:

  • (String)


2561
2562
2563
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2561

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


2566
2567
2568
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2566

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


2571
2572
2573
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2571

def successful_probe_count
  @successful_probe_count
end

#verify_timeString

The time that reachability was assessed through active probing. Corresponds to the JSON property verifyTime

Returns:

  • (String)


2576
2577
2578
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2576

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2583

def update!(**args)
  @abort_cause = args[:abort_cause] if args.key?(:abort_cause)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @edge_responses = args[:edge_responses] if args.key?(:edge_responses)
  @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info)
  @error = args[:error] if args.key?(:error)
  @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end