Class: Google::Apis::NetworkmanagementV1beta1::ReachabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Results of the configuration analysis from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachabilityDetails

Returns a new instance of ReachabilityDetails.



2850
2851
2852
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::NetworkmanagementV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2831
2832
2833
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2831

def error
  @error
end

#resultString

The overall result of the test's configuration analysis. Corresponds to the JSON property result

Returns:

  • (String)


2836
2837
2838
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2836

def result
  @result
end

#tracesArray<Google::Apis::NetworkmanagementV1beta1::Trace>

Result may contain a list of traces if a test has multiple possible paths in the network, such as when destination endpoint is a load balancer with multiple backends. Corresponds to the JSON property traces



2843
2844
2845
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2843

def traces
  @traces
end

#verify_timeString

The time of the configuration analysis. Corresponds to the JSON property verifyTime

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2848

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2855
2856
2857
2858
2859
2860
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2855

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @result = args[:result] if args.key?(:result)
  @traces = args[:traces] if args.key?(:traces)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end