Class: Google::Apis::NetworkmanagementV1beta1::ReachabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Results of the configuration analysis from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachabilityDetails

Returns a new instance of ReachabilityDetails.



2740
2741
2742
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::NetworkmanagementV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2721
2722
2723
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2721

def error
  @error
end

#resultString

The overall result of the test's configuration analysis. Corresponds to the JSON property result

Returns:

  • (String)


2726
2727
2728
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2726

def result
  @result
end

#tracesArray<Google::Apis::NetworkmanagementV1beta1::Trace>

Result may contain a list of traces if a test has multiple possible paths in the network, such as when destination endpoint is a load balancer with multiple backends. Corresponds to the JSON property traces



2733
2734
2735
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2733

def traces
  @traces
end

#verify_timeString

The time of the configuration analysis. Corresponds to the JSON property verifyTime

Returns:

  • (String)


2738
2739
2740
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2738

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2745
2746
2747
2748
2749
2750
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2745

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @result = args[:result] if args.key?(:result)
  @traces = args[:traces] if args.key?(:traces)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end