Class: Google::Apis::NetworkmanagementV1beta1::ReachabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Results of the configuration analysis from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachabilityDetails

Returns a new instance of ReachabilityDetails.



2720
2721
2722
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::NetworkmanagementV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2701
2702
2703
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2701

def error
  @error
end

#resultString

The overall result of the test's configuration analysis. Corresponds to the JSON property result

Returns:

  • (String)


2706
2707
2708
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2706

def result
  @result
end

#tracesArray<Google::Apis::NetworkmanagementV1beta1::Trace>

Result may contain a list of traces if a test has multiple possible paths in the network, such as when destination endpoint is a load balancer with multiple backends. Corresponds to the JSON property traces



2713
2714
2715
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2713

def traces
  @traces
end

#verify_timeString

The time of the configuration analysis. Corresponds to the JSON property verifyTime

Returns:

  • (String)


2718
2719
2720
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2718

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2725
2726
2727
2728
2729
2730
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2725

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @result = args[:result] if args.key?(:result)
  @traces = args[:traces] if args.key?(:traces)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end