Class: Google::Apis::NetworkmanagementV1beta1::RedisClusterInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Redis Cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedisClusterInfo

Returns a new instance of RedisClusterInfo.



2618
2619
2620
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_endpoint_ip_addressString

Discovery endpoint IP address of a Redis Cluster. Corresponds to the JSON property discoveryEndpointIpAddress

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2588

def discovery_endpoint_ip_address
  @discovery_endpoint_ip_address
end

#display_nameString

Name of a Redis Cluster. Corresponds to the JSON property displayName

Returns:

  • (String)


2593
2594
2595
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2593

def display_name
  @display_name
end

#locationString

Name of the region in which the Redis Cluster is defined. For example, "us- central1". Corresponds to the JSON property location

Returns:

  • (String)


2599
2600
2601
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2599

def location
  @location
end

#network_uriString

URI of the network containing the Redis Cluster endpoints in format "projects/ project_id/global/networks/network_id". Corresponds to the JSON property networkUri

Returns:

  • (String)


2605
2606
2607
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2605

def network_uri
  @network_uri
end

#secondary_endpoint_ip_addressString

Secondary endpoint IP address of a Redis Cluster. Corresponds to the JSON property secondaryEndpointIpAddress

Returns:

  • (String)


2610
2611
2612
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2610

def secondary_endpoint_ip_address
  @secondary_endpoint_ip_address
end

#uriString

URI of a Redis Cluster in format "projects/project_id/locations/location/ clusters/cluster_id" Corresponds to the JSON property uri

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2616

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2623
2624
2625
2626
2627
2628
2629
2630
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2623

def update!(**args)
  @discovery_endpoint_ip_address = args[:discovery_endpoint_ip_address] if args.key?(:discovery_endpoint_ip_address)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location = args[:location] if args.key?(:location)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @secondary_endpoint_ip_address = args[:secondary_endpoint_ip_address] if args.key?(:secondary_endpoint_ip_address)
  @uri = args[:uri] if args.key?(:uri)
end