Class: Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network in format "projects/
project/global/ networks/network". -
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance in format "projects/
project/locations/location/instances/instance" Corresponds to the JSON propertyuri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
2951 2952 2953 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
2922 2923 2924 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2922 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network in format "projects/project/global/
networks/network".
Corresponds to the JSON property networkUri
2928 2929 2930 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2928 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
2933 2934 2935 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2933 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
2938 2939 2940 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2938 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
2943 2944 2945 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2943 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance in format "projects/project/locations/
location/instances/instance"
Corresponds to the JSON property uri
2949 2950 2951 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2949 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2956 2957 2958 2959 2960 2961 2962 2963 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2956 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |