Class: Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
-
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
2839 2840 2841 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
2812 2813 2814 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2812 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
Corresponds to the JSON property networkUri
2817 2818 2819 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2817 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
2822 2823 2824 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2822 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
2827 2828 2829 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2827 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
2832 2833 2834 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2832 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance.
Corresponds to the JSON property uri
2837 2838 2839 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2837 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2844 2845 2846 2847 2848 2849 2850 2851 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2844 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |