Class: Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
-
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
2819 2820 2821 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
2792 2793 2794 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2792 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
Corresponds to the JSON property networkUri
2797 2798 2799 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2797 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
2802 2803 2804 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2802 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
2807 2808 2809 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2807 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
2812 2813 2814 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2812 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance.
Corresponds to the JSON property uri
2817 2818 2819 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2817 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2824 2825 2826 2827 2828 2829 2830 2831 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2824 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |