Class: Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
-
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
2667 2668 2669 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
2640 2641 2642 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2640 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
Corresponds to the JSON property networkUri
2645 2646 2647 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2645 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
2650 2651 2652 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2650 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
2655 2656 2657 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2655 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
2660 2661 2662 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2660 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance.
Corresponds to the JSON property uri
2665 2666 2667 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2665 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2672 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |