Class: Google::Apis::NetworkmanagementV1beta1::RouteInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RouteInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine route.
Instance Attribute Summary collapse
-
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e.
-
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix in format "projects/
project/regions/region/routers/router". -
#dest_ip_range ⇒ String
Destination IP range of the route.
-
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route.
-
#display_name ⇒ String
Name of a route.
-
#instance_tags ⇒ Array<String>
Instance tags of the route.
-
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
-
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by in format "projects/
project/ locations/global/hubs/hub". -
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke in format "projects/
project/locations/location/spokes/spoke" (regional) or "projects/project/locations/global/ spokes/spoke" (global). -
#network_uri ⇒ String
URI of a VPC network where route is located in format "projects/
project/ global/networks/network". -
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
-
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located in format " projects/
project/global/networks/network". -
#next_hop_type ⇒ String
Type of next hop.
-
#next_hop_uri ⇒ String
URI of the next hop resource.
-
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
-
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
-
#priority ⇒ Fixnum
Priority of the route.
-
#protocols ⇒ Array<String>
Protocols of the route.
-
#region ⇒ String
Region of the route.
-
#route_scope ⇒ String
Indicates where route is applicable.
-
#route_type ⇒ String
Type of route.
-
#src_ip_range ⇒ String
Source IP address range of the route.
-
#src_port_ranges ⇒ Array<String>
Source port ranges of the route.
-
#uri ⇒ String
URI of a route in format "projects/
project/global/routes/route".
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteInfo
constructor
A new instance of RouteInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteInfo
Returns a new instance of RouteInfo.
3128 3129 3130 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid
endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the
advertised prefix is advertised through, or URI of the source peered network.
Deprecated in favor of the next_hop_uri field, not used in new tests.
Corresponds to the JSON property advertisedRouteNextHopUri
2989 2990 2991 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2989 def advertised_route_next_hop_uri @advertised_route_next_hop_uri end |
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the
corresponding IP prefix in format "projects/project/regions/region/routers/
router".
Corresponds to the JSON property advertisedRouteSourceRouterUri
2996 2997 2998 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2996 def advertised_route_source_router_uri @advertised_route_source_router_uri end |
#dest_ip_range ⇒ String
Destination IP range of the route.
Corresponds to the JSON property destIpRange
3001 3002 3003 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3001 def dest_ip_range @dest_ip_range end |
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property destPortRanges
3006 3007 3008 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3006 def dest_port_ranges @dest_port_ranges end |
#display_name ⇒ String
Name of a route.
Corresponds to the JSON property displayName
3011 3012 3013 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3011 def display_name @display_name end |
#instance_tags ⇒ Array<String>
Instance tags of the route.
Corresponds to the JSON property instanceTags
3016 3017 3018 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3016 def @instance_tags end |
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub,
the URI of the corresponding route in NCC Hub's routing table. Format:
projects/project_id/locations/global/hubs/hub_id/routeTables/
route_table_id/routes/route_id`
Corresponds to the JSON propertynccHubRouteUri`
3024 3025 3026 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3024 def ncc_hub_route_uri @ncc_hub_route_uri end |
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by in format "projects/project/
locations/global/hubs/hub". PEERING_SUBNET and PEERING_DYNAMIC routes that
are advertised by NCC Hub only.
Corresponds to the JSON property nccHubUri
3031 3032 3033 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3031 def ncc_hub_uri @ncc_hub_uri end |
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke in format "projects/project/locations/
location/spokes/spoke" (regional) or "projects/project/locations/global/
spokes/spoke" (global). PEERING_SUBNET and PEERING_DYNAMIC routes that are
advertised by NCC Hub only.
Corresponds to the JSON property nccSpokeUri
3039 3040 3041 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3039 def ncc_spoke_uri @ncc_spoke_uri end |
#network_uri ⇒ String
URI of a VPC network where route is located in format "projects/project/
global/networks/network".
Corresponds to the JSON property networkUri
3045 3046 3047 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3045 def network_uri @network_uri end |
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in
new tests.
Corresponds to the JSON property nextHop
3052 3053 3054 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3052 def next_hop @next_hop end |
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located in format "
projects/project/global/networks/network".
Corresponds to the JSON property nextHopNetworkUri
3058 3059 3060 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3058 def next_hop_network_uri @next_hop_network_uri end |
#next_hop_type ⇒ String
Type of next hop.
Corresponds to the JSON property nextHopType
3063 3064 3065 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3063 def next_hop_type @next_hop_type end |
#next_hop_uri ⇒ String
URI of the next hop resource.
Corresponds to the JSON property nextHopUri
3068 3069 3070 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3068 def next_hop_uri @next_hop_uri end |
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the
originating SUBNET/STATIC/DYNAMIC route.
Corresponds to the JSON property originatingRouteDisplayName
3074 3075 3076 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3074 def originating_route_display_name @originating_route_display_name end |
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating
SUBNET/STATIC route. Format: projects/project_id/global/routes/route_id`
Corresponds to the JSON propertyoriginatingRouteUri`
3080 3081 3082 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3080 def originating_route_uri @originating_route_uri end |
#priority ⇒ Fixnum
Priority of the route.
Corresponds to the JSON property priority
3085 3086 3087 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3085 def priority @priority end |
#protocols ⇒ Array<String>
Protocols of the route. POLICY_BASED routes only.
Corresponds to the JSON property protocols
3090 3091 3092 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3090 def protocols @protocols end |
#region ⇒ String
Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED
routes only. If set for POLICY_BASED route, this is a region of VLAN
attachments for Cloud Interconnect the route applies to. If set to "all" for
POLICY_BASED route, the route applies to VLAN attachments of Cloud
Interconnect in all regions.
Corresponds to the JSON property region
3099 3100 3101 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3099 def region @region end |
#route_scope ⇒ String
Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are
not included in the trace in new tests.
Corresponds to the JSON property routeScope
3105 3106 3107 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3105 def route_scope @route_scope end |
#route_type ⇒ String
Type of route.
Corresponds to the JSON property routeType
3110 3111 3112 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3110 def route_type @route_type end |
#src_ip_range ⇒ String
Source IP address range of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcIpRange
3115 3116 3117 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3115 def src_ip_range @src_ip_range end |
#src_port_ranges ⇒ Array<String>
Source port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcPortRanges
3120 3121 3122 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3120 def src_port_ranges @src_port_ranges end |
#uri ⇒ String
URI of a route in format "projects/project/global/routes/route". SUBNET,
STATIC, PEERING_SUBNET (only for peering network) and POLICY_BASED routes only.
Corresponds to the JSON property uri
3126 3127 3128 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3126 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3133 def update!(**args) @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri) @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri) @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range) @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges) @display_name = args[:display_name] if args.key?(:display_name) @instance_tags = args[:instance_tags] if args.key?(:instance_tags) @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri) @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri) @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri) @network_uri = args[:network_uri] if args.key?(:network_uri) @next_hop = args[:next_hop] if args.key?(:next_hop) @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri) @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type) @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri) @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name) @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri) @priority = args[:priority] if args.key?(:priority) @protocols = args[:protocols] if args.key?(:protocols) @region = args[:region] if args.key?(:region) @route_scope = args[:route_scope] if args.key?(:route_scope) @route_type = args[:route_type] if args.key?(:route_type) @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range) @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges) @uri = args[:uri] if args.key?(:uri) end |