Class: Google::Apis::NetworkmanagementV1beta1::RouteInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteInfo

Returns a new instance of RouteInfo.



3048
3049
3050
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_route_next_hop_uriString

For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the advertised prefix is advertised through, or URI of the source peered network. Deprecated in favor of the next_hop_uri field, not used in new tests. Corresponds to the JSON property advertisedRouteNextHopUri

Returns:

  • (String)


2917
2918
2919
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2917

def advertised_route_next_hop_uri
  @advertised_route_next_hop_uri
end

#advertised_route_source_router_uriString

For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix. Corresponds to the JSON property advertisedRouteSourceRouterUri

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2923

def advertised_route_source_router_uri
  @advertised_route_source_router_uri
end

#dest_ip_rangeString

Destination IP range of the route. Corresponds to the JSON property destIpRange

Returns:

  • (String)


2928
2929
2930
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2928

def dest_ip_range
  @dest_ip_range
end

#dest_port_rangesArray<String>

Destination port ranges of the route. POLICY_BASED routes only. Corresponds to the JSON property destPortRanges

Returns:

  • (Array<String>)


2933
2934
2935
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2933

def dest_port_ranges
  @dest_port_ranges
end

#display_nameString

Name of a route. Corresponds to the JSON property displayName

Returns:

  • (String)


2938
2939
2940
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2938

def display_name
  @display_name
end

#instance_tagsArray<String>

Instance tags of the route. Corresponds to the JSON property instanceTags

Returns:

  • (Array<String>)


2943
2944
2945
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2943

def instance_tags
  @instance_tags
end

#ncc_hub_route_uriString

For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table. Corresponds to the JSON property nccHubRouteUri

Returns:

  • (String)


2949
2950
2951
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2949

def ncc_hub_route_uri
  @ncc_hub_route_uri
end

#ncc_hub_uriString

URI of the NCC Hub the route is advertised by. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only. Corresponds to the JSON property nccHubUri

Returns:

  • (String)


2955
2956
2957
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2955

def ncc_hub_uri
  @ncc_hub_uri
end

#ncc_spoke_uriString

URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only. Corresponds to the JSON property nccSpokeUri

Returns:

  • (String)


2961
2962
2963
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2961

def ncc_spoke_uri
  @ncc_spoke_uri
end

#network_uriString

URI of a VPC network where route is located. Corresponds to the JSON property networkUri

Returns:

  • (String)


2966
2967
2968
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2966

def network_uri
  @network_uri
end

#next_hopString

String type of the next hop of the route (for example, "VPN tunnel"). Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in new tests. Corresponds to the JSON property nextHop

Returns:

  • (String)


2973
2974
2975
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2973

def next_hop
  @next_hop
end

#next_hop_network_uriString

URI of a VPC network where the next hop resource is located. Corresponds to the JSON property nextHopNetworkUri

Returns:

  • (String)


2978
2979
2980
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2978

def next_hop_network_uri
  @next_hop_network_uri
end

#next_hop_typeString

Type of next hop. Corresponds to the JSON property nextHopType

Returns:

  • (String)


2983
2984
2985
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2983

def next_hop_type
  @next_hop_type
end

#next_hop_uriString

URI of the next hop resource. Corresponds to the JSON property nextHopUri

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2988

def next_hop_uri
  @next_hop_uri
end

#originating_route_display_nameString

For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route. Corresponds to the JSON property originatingRouteDisplayName

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2994

def originating_route_display_name
  @originating_route_display_name
end

#originating_route_uriString

For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route. Corresponds to the JSON property originatingRouteUri

Returns:

  • (String)


3000
3001
3002
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3000

def originating_route_uri
  @originating_route_uri
end

#priorityFixnum

Priority of the route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


3005
3006
3007
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3005

def priority
  @priority
end

#protocolsArray<String>

Protocols of the route. POLICY_BASED routes only. Corresponds to the JSON property protocols

Returns:

  • (Array<String>)


3010
3011
3012
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3010

def protocols
  @protocols
end

#regionString

Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED routes only. If set for POLICY_BASED route, this is a region of VLAN attachments for Cloud Interconnect the route applies to. If set to "all" for POLICY_BASED route, the route applies to VLAN attachments of Cloud Interconnect in all regions. Corresponds to the JSON property region

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3019

def region
  @region
end

#route_scopeString

Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are not included in the trace in new tests. Corresponds to the JSON property routeScope

Returns:

  • (String)


3025
3026
3027
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3025

def route_scope
  @route_scope
end

#route_typeString

Type of route. Corresponds to the JSON property routeType

Returns:

  • (String)


3030
3031
3032
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3030

def route_type
  @route_type
end

#src_ip_rangeString

Source IP address range of the route. POLICY_BASED routes only. Corresponds to the JSON property srcIpRange

Returns:

  • (String)


3035
3036
3037
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3035

def src_ip_range
  @src_ip_range
end

#src_port_rangesArray<String>

Source port ranges of the route. POLICY_BASED routes only. Corresponds to the JSON property srcPortRanges

Returns:

  • (Array<String>)


3040
3041
3042
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3040

def src_port_ranges
  @src_port_ranges
end

#uriString

URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and POLICY_BASED routes only. Corresponds to the JSON property uri

Returns:

  • (String)


3046
3047
3048
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3046

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3053

def update!(**args)
  @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri)
  @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri)
  @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range)
  @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_tags = args[:instance_tags] if args.key?(:instance_tags)
  @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri)
  @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri)
  @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @next_hop = args[:next_hop] if args.key?(:next_hop)
  @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri)
  @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type)
  @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri)
  @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name)
  @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri)
  @priority = args[:priority] if args.key?(:priority)
  @protocols = args[:protocols] if args.key?(:protocols)
  @region = args[:region] if args.key?(:region)
  @route_scope = args[:route_scope] if args.key?(:route_scope)
  @route_type = args[:route_type] if args.key?(:route_type)
  @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range)
  @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges)
  @uri = args[:uri] if args.key?(:uri)
end