Class: Google::Apis::NetworkmanagementV1beta1::RouteInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::RouteInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine route.
Instance Attribute Summary collapse
-
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e.
-
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix.
-
#dest_ip_range ⇒ String
Destination IP range of the route.
-
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route.
-
#display_name ⇒ String
Name of a route.
-
#instance_tags ⇒ Array<String>
Instance tags of the route.
-
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
-
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by.
-
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke.
-
#network_uri ⇒ String
URI of a VPC network where route is located.
-
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
-
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
-
#next_hop_type ⇒ String
Type of next hop.
-
#next_hop_uri ⇒ String
URI of the next hop resource.
-
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
-
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
-
#priority ⇒ Fixnum
Priority of the route.
-
#protocols ⇒ Array<String>
Protocols of the route.
-
#region ⇒ String
Region of the route.
-
#route_scope ⇒ String
Indicates where route is applicable.
-
#route_type ⇒ String
Type of route.
-
#src_ip_range ⇒ String
Source IP address range of the route.
-
#src_port_ranges ⇒ Array<String>
Source port ranges of the route.
-
#uri ⇒ String
URI of a route.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteInfo
constructor
A new instance of RouteInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteInfo
Returns a new instance of RouteInfo.
3017 3018 3019 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid
endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the
advertised prefix is advertised through, or URI of the source peered network.
Deprecated in favor of the next_hop_uri field, not used in new tests.
Corresponds to the JSON property advertisedRouteNextHopUri
2886 2887 2888 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2886 def advertised_route_next_hop_uri @advertised_route_next_hop_uri end |
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the
corresponding IP prefix.
Corresponds to the JSON property advertisedRouteSourceRouterUri
2892 2893 2894 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2892 def advertised_route_source_router_uri @advertised_route_source_router_uri end |
#dest_ip_range ⇒ String
Destination IP range of the route.
Corresponds to the JSON property destIpRange
2897 2898 2899 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2897 def dest_ip_range @dest_ip_range end |
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property destPortRanges
2902 2903 2904 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2902 def dest_port_ranges @dest_port_ranges end |
#display_name ⇒ String
Name of a route.
Corresponds to the JSON property displayName
2907 2908 2909 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2907 def display_name @display_name end |
#instance_tags ⇒ Array<String>
Instance tags of the route.
Corresponds to the JSON property instanceTags
2912 2913 2914 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2912 def @instance_tags end |
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub,
the URI of the corresponding route in NCC Hub's routing table.
Corresponds to the JSON property nccHubRouteUri
2918 2919 2920 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2918 def ncc_hub_route_uri @ncc_hub_route_uri end |
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by. PEERING_SUBNET and
PEERING_DYNAMIC routes that are advertised by NCC Hub only.
Corresponds to the JSON property nccHubUri
2924 2925 2926 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2924 def ncc_hub_uri @ncc_hub_uri end |
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes
that are advertised by NCC Hub only.
Corresponds to the JSON property nccSpokeUri
2930 2931 2932 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2930 def ncc_spoke_uri @ncc_spoke_uri end |
#network_uri ⇒ String
URI of a VPC network where route is located.
Corresponds to the JSON property networkUri
2935 2936 2937 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2935 def network_uri @network_uri end |
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in
new tests.
Corresponds to the JSON property nextHop
2942 2943 2944 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2942 def next_hop @next_hop end |
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
Corresponds to the JSON property nextHopNetworkUri
2947 2948 2949 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2947 def next_hop_network_uri @next_hop_network_uri end |
#next_hop_type ⇒ String
Type of next hop.
Corresponds to the JSON property nextHopType
2952 2953 2954 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2952 def next_hop_type @next_hop_type end |
#next_hop_uri ⇒ String
URI of the next hop resource.
Corresponds to the JSON property nextHopUri
2957 2958 2959 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2957 def next_hop_uri @next_hop_uri end |
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the
originating SUBNET/STATIC/DYNAMIC route.
Corresponds to the JSON property originatingRouteDisplayName
2963 2964 2965 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2963 def originating_route_display_name @originating_route_display_name end |
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating
SUBNET/STATIC route.
Corresponds to the JSON property originatingRouteUri
2969 2970 2971 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2969 def originating_route_uri @originating_route_uri end |
#priority ⇒ Fixnum
Priority of the route.
Corresponds to the JSON property priority
2974 2975 2976 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2974 def priority @priority end |
#protocols ⇒ Array<String>
Protocols of the route. POLICY_BASED routes only.
Corresponds to the JSON property protocols
2979 2980 2981 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2979 def protocols @protocols end |
#region ⇒ String
Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED
routes only. If set for POLICY_BASED route, this is a region of VLAN
attachments for Cloud Interconnect the route applies to. If set to "all" for
POLICY_BASED route, the route applies to VLAN attachments of Cloud
Interconnect in all regions.
Corresponds to the JSON property region
2988 2989 2990 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2988 def region @region end |
#route_scope ⇒ String
Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are
not included in the trace in new tests.
Corresponds to the JSON property routeScope
2994 2995 2996 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2994 def route_scope @route_scope end |
#route_type ⇒ String
Type of route.
Corresponds to the JSON property routeType
2999 3000 3001 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 2999 def route_type @route_type end |
#src_ip_range ⇒ String
Source IP address range of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcIpRange
3004 3005 3006 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3004 def src_ip_range @src_ip_range end |
#src_port_ranges ⇒ Array<String>
Source port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcPortRanges
3009 3010 3011 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3009 def src_port_ranges @src_port_ranges end |
#uri ⇒ String
URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and
POLICY_BASED routes only.
Corresponds to the JSON property uri
3015 3016 3017 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3015 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3022 def update!(**args) @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri) @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri) @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range) @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges) @display_name = args[:display_name] if args.key?(:display_name) @instance_tags = args[:instance_tags] if args.key?(:instance_tags) @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri) @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri) @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri) @network_uri = args[:network_uri] if args.key?(:network_uri) @next_hop = args[:next_hop] if args.key?(:next_hop) @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri) @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type) @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri) @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name) @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri) @priority = args[:priority] if args.key?(:priority) @protocols = args[:protocols] if args.key?(:protocols) @region = args[:region] if args.key?(:region) @route_scope = args[:route_scope] if args.key?(:route_scope) @route_type = args[:route_type] if args.key?(:route_type) @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range) @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges) @uri = args[:uri] if args.key?(:uri) end |