Class: Google::Apis::NetworkmanagementV1beta1::SingleEdgeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Probing results for a single edge device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleEdgeResponse

Returns a new instance of SingleEdgeResponse.



3240
3241
3242
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_egress_locationGoogle::Apis::NetworkmanagementV1beta1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



3212
3213
3214
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3212

def destination_egress_location
  @destination_egress_location
end

#destination_routerString

Router name in the format 'router.metroshard'. For example: pf01.aaa01, pr02.aaa01. Corresponds to the JSON property destinationRouter

Returns:

  • (String)


3218
3219
3220
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3218

def destination_router
  @destination_router
end

#probing_latencyGoogle::Apis::NetworkmanagementV1beta1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



3223
3224
3225
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3223

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing for this egress device. Corresponds to the JSON property result

Returns:

  • (String)


3228
3229
3230
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3228

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


3233
3234
3235
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3233

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


3238
3239
3240
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3238

def successful_probe_count
  @successful_probe_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3245

def update!(**args)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @destination_router = args[:destination_router] if args.key?(:destination_router)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
end