Class: Google::Apis::NetworkmanagementV1beta1::SingleEdgeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

Probing results for a single edge device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleEdgeResponse

Returns a new instance of SingleEdgeResponse.



3200
3201
3202
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_egress_locationGoogle::Apis::NetworkmanagementV1beta1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



3172
3173
3174
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3172

def destination_egress_location
  @destination_egress_location
end

#destination_routerString

Router name in the format 'router.metroshard'. For example: pf01.aaa01, pr02.aaa01. Corresponds to the JSON property destinationRouter

Returns:

  • (String)


3178
3179
3180
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3178

def destination_router
  @destination_router
end

#probing_latencyGoogle::Apis::NetworkmanagementV1beta1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



3183
3184
3185
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3183

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing for this egress device. Corresponds to the JSON property result

Returns:

  • (String)


3188
3189
3190
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3188

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


3193
3194
3195
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3193

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


3198
3199
3200
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3198

def successful_probe_count
  @successful_probe_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3205

def update!(**args)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @destination_router = args[:destination_router] if args.key?(:destination_router)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
end