Class: Google::Apis::NetworkmanagementV1beta1::Step

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

A simulated forwarding path is composed of multiple steps. Each step has a well-defined state and an associated configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Step

Returns a new instance of Step.



3610
3611
3612
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abortGoogle::Apis::NetworkmanagementV1beta1::AbortInfo

Details of the final state "abort" and associated resource. Corresponds to the JSON property abort



3383
3384
3385
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3383

def abort
  @abort
end

#app_engine_versionGoogle::Apis::NetworkmanagementV1beta1::AppEngineVersionInfo

For display only. Metadata associated with an App Engine version. Corresponds to the JSON property appEngineVersion



3388
3389
3390
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3388

def app_engine_version
  @app_engine_version
end

#causes_dropBoolean Also known as: causes_drop?

This is a step that leads to the final state Drop. Corresponds to the JSON property causesDrop

Returns:

  • (Boolean)


3393
3394
3395
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3393

def causes_drop
  @causes_drop
end

#cloud_functionGoogle::Apis::NetworkmanagementV1beta1::CloudFunctionInfo

For display only. Metadata associated with a Cloud Function. Corresponds to the JSON property cloudFunction



3399
3400
3401
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3399

def cloud_function
  @cloud_function
end

#cloud_run_jobGoogle::Apis::NetworkmanagementV1beta1::CloudRunJobInfo

For display only. Metadata associated with a Cloud Run job. Corresponds to the JSON property cloudRunJob



3404
3405
3406
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3404

def cloud_run_job
  @cloud_run_job
end

#cloud_run_revisionGoogle::Apis::NetworkmanagementV1beta1::CloudRunRevisionInfo

For display only. Metadata associated with a Cloud Run revision. Corresponds to the JSON property cloudRunRevision



3409
3410
3411
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3409

def cloud_run_revision
  @cloud_run_revision
end

#cloud_sql_instanceGoogle::Apis::NetworkmanagementV1beta1::CloudSqlInstanceInfo

For display only. Metadata associated with a Cloud SQL instance. Corresponds to the JSON property cloudSqlInstance



3414
3415
3416
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3414

def cloud_sql_instance
  @cloud_sql_instance
end

#datastream_private_connectionGoogle::Apis::NetworkmanagementV1beta1::PrivateConnectionInfo

For display only. Metadata associated with a Private Connection. Corresponds to the JSON property datastreamPrivateConnection



3419
3420
3421
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3419

def datastream_private_connection
  @datastream_private_connection
end

#deliverGoogle::Apis::NetworkmanagementV1beta1::DeliverInfo

Details of the final state "deliver" and associated resource. Corresponds to the JSON property deliver



3424
3425
3426
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3424

def deliver
  @deliver
end

#descriptionString

A description of the step. Usually this is a summary of the state. Corresponds to the JSON property description

Returns:

  • (String)


3429
3430
3431
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3429

def description
  @description
end

#direct_vpc_egress_connectionGoogle::Apis::NetworkmanagementV1beta1::DirectVpcEgressConnectionInfo

For display only. Metadata associated with a serverless direct VPC egress connection. Corresponds to the JSON property directVpcEgressConnection



3435
3436
3437
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3435

def direct_vpc_egress_connection
  @direct_vpc_egress_connection
end

#dms_private_connectionGoogle::Apis::NetworkmanagementV1beta1::PrivateConnectionInfo

For display only. Metadata associated with a Private Connection. Corresponds to the JSON property dmsPrivateConnection



3440
3441
3442
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3440

def dms_private_connection
  @dms_private_connection
end

#dropGoogle::Apis::NetworkmanagementV1beta1::DropInfo

Details of the final state "drop" and associated resource. Corresponds to the JSON property drop



3445
3446
3447
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3445

def drop
  @drop
end

#endpointGoogle::Apis::NetworkmanagementV1beta1::EndpointInfo

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model. Corresponds to the JSON property endpoint



3452
3453
3454
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3452

def endpoint
  @endpoint
end

#firewallGoogle::Apis::NetworkmanagementV1beta1::FirewallInfo

For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule. Corresponds to the JSON property firewall



3458
3459
3460
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3458

def firewall
  @firewall
end

#forwardGoogle::Apis::NetworkmanagementV1beta1::ForwardInfo

Details of the final state "forward" and associated resource. Corresponds to the JSON property forward



3463
3464
3465
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3463

def forward
  @forward
end

#forwarding_ruleGoogle::Apis::NetworkmanagementV1beta1::ForwardingRuleInfo

For display only. Metadata associated with a Compute Engine forwarding rule. Corresponds to the JSON property forwardingRule



3468
3469
3470
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3468

def forwarding_rule
  @forwarding_rule
end

#gke_masterGoogle::Apis::NetworkmanagementV1beta1::GkeMasterInfo

For display only. Metadata associated with a Google Kubernetes Engine (GKE) cluster master. Corresponds to the JSON property gkeMaster



3474
3475
3476
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3474

def gke_master
  @gke_master
end

#gke_network_policyGoogle::Apis::NetworkmanagementV1beta1::GkeNetworkPolicyInfo

For display only. Metadata associated with a GKE Network Policy. Corresponds to the JSON property gkeNetworkPolicy



3479
3480
3481
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3479

def gke_network_policy
  @gke_network_policy
end

#gke_network_policy_skippedGoogle::Apis::NetworkmanagementV1beta1::GkeNetworkPolicySkippedInfo

For display only. Contains information about why GKE Network Policy evaluation was skipped. Corresponds to the JSON property gkeNetworkPolicySkipped



3485
3486
3487
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3485

def gke_network_policy_skipped
  @gke_network_policy_skipped
end

#gke_podGoogle::Apis::NetworkmanagementV1beta1::GkePodInfo

For display only. Metadata associated with a Google Kubernetes Engine (GKE) Pod. Corresponds to the JSON property gkePod



3491
3492
3493
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3491

def gke_pod
  @gke_pod
end

#google_serviceGoogle::Apis::NetworkmanagementV1beta1::GoogleServiceInfo

For display only. Details of a Google Service sending packets to a VPC network. Although the source IP might be a publicly routable address, some Google Services use special routes within Google production infrastructure to reach Compute Engine Instances. https://cloud.google.com/vpc/docs/routes# special_return_paths Corresponds to the JSON property googleService



3500
3501
3502
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3500

def google_service
  @google_service
end

#hybrid_subnetGoogle::Apis::NetworkmanagementV1beta1::HybridSubnetInfo

For display only. Metadata associated with a hybrid subnet. Corresponds to the JSON property hybridSubnet



3505
3506
3507
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3505

def hybrid_subnet
  @hybrid_subnet
end

#instanceGoogle::Apis::NetworkmanagementV1beta1::InstanceInfo

For display only. Metadata associated with a Compute Engine instance. Corresponds to the JSON property instance



3510
3511
3512
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3510

def instance
  @instance
end

#interconnect_attachmentGoogle::Apis::NetworkmanagementV1beta1::InterconnectAttachmentInfo

For display only. Metadata associated with an Interconnect attachment. Corresponds to the JSON property interconnectAttachment



3515
3516
3517
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3515

def interconnect_attachment
  @interconnect_attachment
end

#ip_masquerading_skippedGoogle::Apis::NetworkmanagementV1beta1::IpMasqueradingSkippedInfo

For display only. Contains information about why IP masquerading was skipped for the packet. Corresponds to the JSON property ipMasqueradingSkipped



3521
3522
3523
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3521

def ip_masquerading_skipped
  @ip_masquerading_skipped
end

#load_balancerGoogle::Apis::NetworkmanagementV1beta1::LoadBalancerInfo

For display only. Metadata associated with a load balancer. Corresponds to the JSON property loadBalancer



3526
3527
3528
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3526

def load_balancer
  @load_balancer
end

#load_balancer_backend_infoGoogle::Apis::NetworkmanagementV1beta1::LoadBalancerBackendInfo

For display only. Metadata associated with the load balancer backend. Corresponds to the JSON property loadBalancerBackendInfo



3531
3532
3533
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3531

def load_balancer_backend_info
  @load_balancer_backend_info
end

#natGoogle::Apis::NetworkmanagementV1beta1::NatInfo

For display only. Metadata associated with NAT. Corresponds to the JSON property nat



3536
3537
3538
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3536

def nat
  @nat
end

#networkGoogle::Apis::NetworkmanagementV1beta1::NetworkInfo

For display only. Metadata associated with a Compute Engine network. Corresponds to the JSON property network



3541
3542
3543
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3541

def network
  @network
end

#ngfw_packet_inspectionGoogle::Apis::NetworkmanagementV1beta1::NgfwPacketInspectionInfo

For display only. Metadata associated with a layer 7 packet inspection by the firewall. Corresponds to the JSON property ngfwPacketInspection



3547
3548
3549
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3547

def ngfw_packet_inspection
  @ngfw_packet_inspection
end

#project_idString

Project ID that contains the configuration this step is validating. Corresponds to the JSON property projectId

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3552

def project_id
  @project_id
end

#proxy_connectionGoogle::Apis::NetworkmanagementV1beta1::ProxyConnectionInfo

For display only. Metadata associated with ProxyConnection. Corresponds to the JSON property proxyConnection



3557
3558
3559
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3557

def proxy_connection
  @proxy_connection
end

#redis_clusterGoogle::Apis::NetworkmanagementV1beta1::RedisClusterInfo

For display only. Metadata associated with a Redis Cluster. Corresponds to the JSON property redisCluster



3562
3563
3564
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3562

def redis_cluster
  @redis_cluster
end

#redis_instanceGoogle::Apis::NetworkmanagementV1beta1::RedisInstanceInfo

For display only. Metadata associated with a Cloud Redis Instance. Corresponds to the JSON property redisInstance



3567
3568
3569
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3567

def redis_instance
  @redis_instance
end

#routeGoogle::Apis::NetworkmanagementV1beta1::RouteInfo

For display only. Metadata associated with a Compute Engine route. Corresponds to the JSON property route



3572
3573
3574
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3572

def route
  @route
end

#serverless_external_connectionGoogle::Apis::NetworkmanagementV1beta1::ServerlessExternalConnectionInfo

For display only. Metadata associated with a serverless public connection. Corresponds to the JSON property serverlessExternalConnection



3577
3578
3579
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3577

def serverless_external_connection
  @serverless_external_connection
end

#serverless_negGoogle::Apis::NetworkmanagementV1beta1::ServerlessNegInfo

For display only. Metadata associated with the serverless network endpoint group backend. Corresponds to the JSON property serverlessNeg



3583
3584
3585
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3583

def serverless_neg
  @serverless_neg
end

#stateString

Each step is in one of the pre-defined states. Corresponds to the JSON property state

Returns:

  • (String)


3588
3589
3590
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3588

def state
  @state
end

#storage_bucketGoogle::Apis::NetworkmanagementV1beta1::StorageBucketInfo

For display only. Metadata associated with Storage Bucket. Corresponds to the JSON property storageBucket



3593
3594
3595
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3593

def storage_bucket
  @storage_bucket
end

#vpc_connectorGoogle::Apis::NetworkmanagementV1beta1::VpcConnectorInfo

For display only. Metadata associated with a VPC connector. Corresponds to the JSON property vpcConnector



3598
3599
3600
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3598

def vpc_connector
  @vpc_connector
end

#vpn_gatewayGoogle::Apis::NetworkmanagementV1beta1::VpnGatewayInfo

For display only. Metadata associated with a Compute Engine VPN gateway. Corresponds to the JSON property vpnGateway



3603
3604
3605
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3603

def vpn_gateway
  @vpn_gateway
end

#vpn_tunnelGoogle::Apis::NetworkmanagementV1beta1::VpnTunnelInfo

For display only. Metadata associated with a Compute Engine VPN tunnel. Corresponds to the JSON property vpnTunnel



3608
3609
3610
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3608

def vpn_tunnel
  @vpn_tunnel
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3615

def update!(**args)
  @abort = args[:abort] if args.key?(:abort)
  @app_engine_version = args[:app_engine_version] if args.key?(:app_engine_version)
  @causes_drop = args[:causes_drop] if args.key?(:causes_drop)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run_job = args[:cloud_run_job] if args.key?(:cloud_run_job)
  @cloud_run_revision = args[:cloud_run_revision] if args.key?(:cloud_run_revision)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @datastream_private_connection = args[:datastream_private_connection] if args.key?(:datastream_private_connection)
  @deliver = args[:deliver] if args.key?(:deliver)
  @description = args[:description] if args.key?(:description)
  @direct_vpc_egress_connection = args[:direct_vpc_egress_connection] if args.key?(:direct_vpc_egress_connection)
  @dms_private_connection = args[:dms_private_connection] if args.key?(:dms_private_connection)
  @drop = args[:drop] if args.key?(:drop)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @firewall = args[:firewall] if args.key?(:firewall)
  @forward = args[:forward] if args.key?(:forward)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @gke_master = args[:gke_master] if args.key?(:gke_master)
  @gke_network_policy = args[:gke_network_policy] if args.key?(:gke_network_policy)
  @gke_network_policy_skipped = args[:gke_network_policy_skipped] if args.key?(:gke_network_policy_skipped)
  @gke_pod = args[:gke_pod] if args.key?(:gke_pod)
  @google_service = args[:google_service] if args.key?(:google_service)
  @hybrid_subnet = args[:hybrid_subnet] if args.key?(:hybrid_subnet)
  @instance = args[:instance] if args.key?(:instance)
  @interconnect_attachment = args[:interconnect_attachment] if args.key?(:interconnect_attachment)
  @ip_masquerading_skipped = args[:ip_masquerading_skipped] if args.key?(:ip_masquerading_skipped)
  @load_balancer = args[:load_balancer] if args.key?(:load_balancer)
  @load_balancer_backend_info = args[:load_balancer_backend_info] if args.key?(:load_balancer_backend_info)
  @nat = args[:nat] if args.key?(:nat)
  @network = args[:network] if args.key?(:network)
  @ngfw_packet_inspection = args[:ngfw_packet_inspection] if args.key?(:ngfw_packet_inspection)
  @project_id = args[:project_id] if args.key?(:project_id)
  @proxy_connection = args[:proxy_connection] if args.key?(:proxy_connection)
  @redis_cluster = args[:redis_cluster] if args.key?(:redis_cluster)
  @redis_instance = args[:redis_instance] if args.key?(:redis_instance)
  @route = args[:route] if args.key?(:route)
  @serverless_external_connection = args[:serverless_external_connection] if args.key?(:serverless_external_connection)
  @serverless_neg = args[:serverless_neg] if args.key?(:serverless_neg)
  @state = args[:state] if args.key?(:state)
  @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket)
  @vpc_connector = args[:vpc_connector] if args.key?(:vpc_connector)
  @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway)
  @vpn_tunnel = args[:vpn_tunnel] if args.key?(:vpn_tunnel)
end