Class: Google::Apis::NetworkmanagementV1beta1::Trace
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::Trace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
Trace represents one simulated packet forwarding path. * Each trace contains
multiple ordered steps. * Each step is in a particular state with associated
configuration. * State is categorized as final or non-final states. * Each
final state has a reason associated. * Each trace must end with a final state (
the last step). |---------------------Trace----------------------| Step1(
State) Step2(State) --- StepN(State(final))
Instance Attribute Summary collapse
-
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1beta1::EndpointInfo
For display only.
-
#forward_trace_id ⇒ Fixnum
ID of trace.
-
#steps ⇒ Array<Google::Apis::NetworkmanagementV1beta1::Step>
A trace of a test contains multiple steps from the initial state to the final state (delivered, dropped, forwarded, or aborted).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Trace
constructor
A new instance of Trace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Trace
Returns a new instance of Trace.
3594 3595 3596 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1beta1::EndpointInfo
For display only. The specification of the endpoints for the test.
EndpointInfo is derived from source and destination Endpoint and validated by
the backend data plane model.
Corresponds to the JSON property endpointInfo
3576 3577 3578 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3576 def endpoint_info @endpoint_info end |
#forward_trace_id ⇒ Fixnum
ID of trace. For forward traces, this ID is unique for each trace. For return
traces, it matches ID of associated forward trace. A single forward trace can
be associated with none, one or more than one return trace.
Corresponds to the JSON property forwardTraceId
3583 3584 3585 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3583 def forward_trace_id @forward_trace_id end |
#steps ⇒ Array<Google::Apis::NetworkmanagementV1beta1::Step>
A trace of a test contains multiple steps from the initial state to the final
state (delivered, dropped, forwarded, or aborted). The steps are ordered by
the processing sequence within the simulated network state machine. It is
critical to preserve the order of the steps and avoid reordering or sorting
them.
Corresponds to the JSON property steps
3592 3593 3594 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3592 def steps @steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3599 3600 3601 3602 3603 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3599 def update!(**args) @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info) @forward_trace_id = args[:forward_trace_id] if args.key?(:forward_trace_id) @steps = args[:steps] if args.key?(:steps) end |