Class: Google::Apis::NetworkmanagementV1beta1::ViewerPermissionMissingInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::ViewerPermissionMissingInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a step that was redacted due to missing permissions.
Instance Attribute Summary collapse
-
#resource_types ⇒ Array<String>
Types of the resources that the user does not have permission to view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ViewerPermissionMissingInfo
constructor
A new instance of ViewerPermissionMissingInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ViewerPermissionMissingInfo
Returns a new instance of ViewerPermissionMissingInfo.
3798 3799 3800 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_types ⇒ Array<String>
Types of the resources that the user does not have permission to view.
Corresponds to the JSON property resourceTypes
3796 3797 3798 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3796 def resource_types @resource_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3803 3804 3805 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3803 def update!(**args) @resource_types = args[:resource_types] if args.key?(:resource_types) end |