Class: Google::Apis::NetworkmanagementV1beta1::VpnGatewayInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::VpnGatewayInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN gateway.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN gateway.
-
#ip_address ⇒ String
IP address of the VPN gateway.
-
#network_uri ⇒ String
URI of a Compute Engine network where the VPN gateway is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN gateway is configured.
-
#uri ⇒ String
URI of a VPN gateway.
-
#vpn_tunnel_uri ⇒ String
A VPN tunnel that is associated with this VPN gateway.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayInfo
constructor
A new instance of VpnGatewayInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayInfo
Returns a new instance of VpnGatewayInfo.
3886 3887 3888 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN gateway.
Corresponds to the JSON property displayName
3857 3858 3859 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3857 def display_name @display_name end |
#ip_address ⇒ String
IP address of the VPN gateway.
Corresponds to the JSON property ipAddress
3862 3863 3864 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3862 def ip_address @ip_address end |
#network_uri ⇒ String
URI of a Compute Engine network where the VPN gateway is configured.
Corresponds to the JSON property networkUri
3867 3868 3869 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3867 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN gateway is configured.
Corresponds to the JSON property region
3872 3873 3874 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3872 def region @region end |
#uri ⇒ String
URI of a VPN gateway.
Corresponds to the JSON property uri
3877 3878 3879 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3877 def uri @uri end |
#vpn_tunnel_uri ⇒ String
A VPN tunnel that is associated with this VPN gateway. There may be multiple
VPN tunnels configured on a VPN gateway, and only the one relevant to the test
is displayed.
Corresponds to the JSON property vpnTunnelUri
3884 3885 3886 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3884 def vpn_tunnel_uri @vpn_tunnel_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3891 3892 3893 3894 3895 3896 3897 3898 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3891 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) @vpn_tunnel_uri = args[:vpn_tunnel_uri] if args.key?(:vpn_tunnel_uri) end |