Class: Google::Apis::NetworkmanagementV1beta1::VpnGatewayInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::VpnGatewayInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN gateway.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN gateway.
-
#ip_address ⇒ String
IP address of the VPN gateway.
-
#network_uri ⇒ String
URI of a Compute Engine network where the VPN gateway is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN gateway is configured.
-
#uri ⇒ String
URI of a VPN gateway.
-
#vpn_tunnel_uri ⇒ String
A VPN tunnel that is associated with this VPN gateway.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayInfo
constructor
A new instance of VpnGatewayInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayInfo
Returns a new instance of VpnGatewayInfo.
3849 3850 3851 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN gateway.
Corresponds to the JSON property displayName
3820 3821 3822 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3820 def display_name @display_name end |
#ip_address ⇒ String
IP address of the VPN gateway.
Corresponds to the JSON property ipAddress
3825 3826 3827 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3825 def ip_address @ip_address end |
#network_uri ⇒ String
URI of a Compute Engine network where the VPN gateway is configured.
Corresponds to the JSON property networkUri
3830 3831 3832 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3830 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN gateway is configured.
Corresponds to the JSON property region
3835 3836 3837 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3835 def region @region end |
#uri ⇒ String
URI of a VPN gateway.
Corresponds to the JSON property uri
3840 3841 3842 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3840 def uri @uri end |
#vpn_tunnel_uri ⇒ String
A VPN tunnel that is associated with this VPN gateway. There may be multiple
VPN tunnels configured on a VPN gateway, and only the one relevant to the test
is displayed.
Corresponds to the JSON property vpnTunnelUri
3847 3848 3849 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3847 def vpn_tunnel_uri @vpn_tunnel_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3854 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) @vpn_tunnel_uri = args[:vpn_tunnel_uri] if args.key?(:vpn_tunnel_uri) end |