Class: Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN tunnel.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN tunnel.
-
#network_uri ⇒ String
URI of the VPC network where the VPN tunnel is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
-
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
-
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
-
#routing_type ⇒ String
Type of the routing policy.
-
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
-
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
-
#uri ⇒ String
URI of the VPN tunnel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelInfo
constructor
A new instance of VpnTunnelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelInfo
Returns a new instance of VpnTunnelInfo.
4045 4046 4047 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN tunnel.
Corresponds to the JSON property displayName
3995 3996 3997 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3995 def display_name @display_name end |
#network_uri ⇒ String
URI of the VPC network where the VPN tunnel is configured. Format: projects/
project_id/global/networks/network_id`
Corresponds to the JSON propertynetworkUri`
4001 4002 4003 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4001 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
Corresponds to the JSON property region
4006 4007 4008 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4006 def region @region end |
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel. Format: * projects/
project_id/regions/region/vpnGateways/vpn_gateway_id`` (GCP HA VPN gateway)
projects/project_id/global/peerVpnGateways/peer_vpn_gateway_id`(GCP peer VPN gateway) Corresponds to the JSON propertyremoteGateway`
4014 4015 4016 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4014 def remote_gateway @remote_gateway end |
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
Corresponds to the JSON property remoteGatewayIp
4019 4020 4021 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4019 def remote_gateway_ip @remote_gateway_ip end |
#routing_type ⇒ String
Type of the routing policy.
Corresponds to the JSON property routingType
4024 4025 4026 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4024 def routing_type @routing_type end |
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel. Format: * projects/
project_id/regions/region/vpnGateways/vpn_gateway_id(HA VPN gateway) * `
projects/`project_id`/regions/`region`/targetVpnGateways/`
target_vpn_gateway_id (Classic VPN gateway)
Corresponds to the JSON property sourceGateway
4032 4033 4034 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4032 def source_gateway @source_gateway end |
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
Corresponds to the JSON property sourceGatewayIp
4037 4038 4039 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4037 def source_gateway_ip @source_gateway_ip end |
#uri ⇒ String
URI of the VPN tunnel. Format: projects/project_id/regions/region/
vpnTunnels/vpn_tunnel_id`
Corresponds to the JSON propertyuri`
4043 4044 4045 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4043 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 4050 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway) @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip) @routing_type = args[:routing_type] if args.key?(:routing_type) @source_gateway = args[:source_gateway] if args.key?(:source_gateway) @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip) @uri = args[:uri] if args.key?(:uri) end |