Class: Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN tunnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelInfo

Returns a new instance of VpnTunnelInfo.



3950
3951
3952
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN tunnel. Corresponds to the JSON property displayName

Returns:

  • (String)


3908
3909
3910
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3908

def display_name
  @display_name
end

#network_uriString

URI of a Compute Engine network where the VPN tunnel is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


3913
3914
3915
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3913

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN tunnel is configured. Corresponds to the JSON property region

Returns:

  • (String)


3918
3919
3920
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3918

def region
  @region
end

#remote_gatewayString

URI of a VPN gateway at remote end of the tunnel. Corresponds to the JSON property remoteGateway

Returns:

  • (String)


3923
3924
3925
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3923

def remote_gateway
  @remote_gateway
end

#remote_gateway_ipString

Remote VPN gateway's IP address. Corresponds to the JSON property remoteGatewayIp

Returns:

  • (String)


3928
3929
3930
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3928

def remote_gateway_ip
  @remote_gateway_ip
end

#routing_typeString

Type of the routing policy. Corresponds to the JSON property routingType

Returns:

  • (String)


3933
3934
3935
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3933

def routing_type
  @routing_type
end

#source_gatewayString

URI of the VPN gateway at local end of the tunnel. Corresponds to the JSON property sourceGateway

Returns:

  • (String)


3938
3939
3940
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3938

def source_gateway
  @source_gateway
end

#source_gateway_ipString

Local VPN gateway's IP address. Corresponds to the JSON property sourceGatewayIp

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3943

def source_gateway_ip
  @source_gateway_ip
end

#uriString

URI of a VPN tunnel. Corresponds to the JSON property uri

Returns:

  • (String)


3948
3949
3950
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3948

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3955

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway)
  @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip)
  @routing_type = args[:routing_type] if args.key?(:routing_type)
  @source_gateway = args[:source_gateway] if args.key?(:source_gateway)
  @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip)
  @uri = args[:uri] if args.key?(:uri)
end