Class: Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN tunnel.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN tunnel.
-
#network_uri ⇒ String
URI of a Compute Engine network where the VPN tunnel is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
-
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
-
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
-
#routing_type ⇒ String
Type of the routing policy.
-
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
-
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
-
#uri ⇒ String
URI of a VPN tunnel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelInfo
constructor
A new instance of VpnTunnelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelInfo
Returns a new instance of VpnTunnelInfo.
3904 3905 3906 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN tunnel.
Corresponds to the JSON property displayName
3862 3863 3864 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3862 def display_name @display_name end |
#network_uri ⇒ String
URI of a Compute Engine network where the VPN tunnel is configured.
Corresponds to the JSON property networkUri
3867 3868 3869 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3867 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
Corresponds to the JSON property region
3872 3873 3874 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3872 def region @region end |
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
Corresponds to the JSON property remoteGateway
3877 3878 3879 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3877 def remote_gateway @remote_gateway end |
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
Corresponds to the JSON property remoteGatewayIp
3882 3883 3884 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3882 def remote_gateway_ip @remote_gateway_ip end |
#routing_type ⇒ String
Type of the routing policy.
Corresponds to the JSON property routingType
3887 3888 3889 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3887 def routing_type @routing_type end |
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
Corresponds to the JSON property sourceGateway
3892 3893 3894 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3892 def source_gateway @source_gateway end |
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
Corresponds to the JSON property sourceGatewayIp
3897 3898 3899 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3897 def source_gateway_ip @source_gateway_ip end |
#uri ⇒ String
URI of a VPN tunnel.
Corresponds to the JSON property uri
3902 3903 3904 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3902 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3909 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway) @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip) @routing_type = args[:routing_type] if args.key?(:routing_type) @source_gateway = args[:source_gateway] if args.key?(:source_gateway) @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip) @uri = args[:uri] if args.key?(:uri) end |