Class: Google::Apis::NetworkmanagementV1beta1::VpnTunnelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1beta1/classes.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb,
lib/google/apis/networkmanagement_v1beta1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN tunnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelInfo

Returns a new instance of VpnTunnelInfo.



3872
3873
3874
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN tunnel. Corresponds to the JSON property displayName

Returns:

  • (String)


3830
3831
3832
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3830

def display_name
  @display_name
end

#network_uriString

URI of a Compute Engine network where the VPN tunnel is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


3835
3836
3837
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3835

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN tunnel is configured. Corresponds to the JSON property region

Returns:

  • (String)


3840
3841
3842
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3840

def region
  @region
end

#remote_gatewayString

URI of a VPN gateway at remote end of the tunnel. Corresponds to the JSON property remoteGateway

Returns:

  • (String)


3845
3846
3847
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3845

def remote_gateway
  @remote_gateway
end

#remote_gateway_ipString

Remote VPN gateway's IP address. Corresponds to the JSON property remoteGatewayIp

Returns:

  • (String)


3850
3851
3852
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3850

def remote_gateway_ip
  @remote_gateway_ip
end

#routing_typeString

Type of the routing policy. Corresponds to the JSON property routingType

Returns:

  • (String)


3855
3856
3857
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3855

def routing_type
  @routing_type
end

#source_gatewayString

URI of the VPN gateway at local end of the tunnel. Corresponds to the JSON property sourceGateway

Returns:

  • (String)


3860
3861
3862
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3860

def source_gateway
  @source_gateway
end

#source_gateway_ipString

Local VPN gateway's IP address. Corresponds to the JSON property sourceGatewayIp

Returns:

  • (String)


3865
3866
3867
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3865

def source_gateway_ip
  @source_gateway_ip
end

#uriString

URI of a VPN tunnel. Corresponds to the JSON property uri

Returns:

  • (String)


3870
3871
3872
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3870

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
# File 'lib/google/apis/networkmanagement_v1beta1/classes.rb', line 3877

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway)
  @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip)
  @routing_type = args[:routing_type] if args.key?(:routing_type)
  @source_gateway = args[:source_gateway] if args.key?(:source_gateway)
  @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip)
  @uri = args[:uri] if args.key?(:uri)
end